import { InjectionToken, Injectable, Inject, EventEmitter, Component, ComponentFactoryResolver, Input, Output, ViewChild, ViewContainerRef, ViewEncapsulation, ChangeDetectionStrategy, HostListener, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { NodeService, TreeActionTypes, NodeDispatcherService, TreeInitializerService, TreeComponent, TreeModule } from '@rign/angular2-tree';
import { HttpClient, HttpParams, HttpClientModule } from '@angular/common/http';
import { CropperSettings } from 'ng2-img-cropper/src/cropperSettings';
import { ImageCropperComponent, ImageCropperModule } from 'ng2-img-cropper';
import { Store, createFeatureSelector, StoreModule } from '@ngrx/store';
import { FileUploader, FileUploadModule } from 'ng2-file-upload';
import { UUID } from 'angular2-uuid';
import { concatMap, map, distinctUntilChanged, withLatestFrom, switchMap, catchError, filter, debounceTime } from 'rxjs/operators';
import { of, fromEvent, Subject, BehaviorSubject, combineLatest, empty, throwError, Observable, Subscription } from 'rxjs';
import { __decorate, __metadata } from 'tslib';
import { ofType, Actions, Effect, EffectsModule } from '@ngrx/effects';
import { FormControl, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { ConfirmationPopoverModule } from 'angular-confirmation-popover';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const FILEMANAGER_TRANSLATION_TOKEN = new InjectionToken('[Filemanager] Fielmanager translation service');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileManagerConfiguration {
    /**
     * @param {?} configuration
     * @param {?} filemanagerTranslations
     */
    constructor(configuration, filemanagerTranslations) {
        this.filemanagerTranslations = filemanagerTranslations;
        this.allowedCropSize = [
            {
                name: this.filemanagerTranslations.RI_FM_BTN_LANDSCAPE,
                width: 300,
                height: 100
            },
            {
                name: this.filemanagerTranslations.RI_FM_BTN_PORTRAIT,
                width: 200,
                height: 300
            }
        ];
        this.contextMenuItems = [];
        this.fileTypesFilter = [
            {
                name: 'ALL',
                mimes: [],
                iconCls: 'fa fa-file-o',
                text: 'All files',
                defaultSelected: true
            },
            {
                name: 'IMAGES',
                mimes: ['image/jpg', 'image/jpeg', 'image/png', 'image/gif', 'image/png'],
                iconCls: 'fa fa-picture-o',
                text: 'Images'
            },
            {
                name: 'AUDIO',
                mimes: ['audio/mpeg', 'audio/x-ms-wma', 'audio/vnd.rn-realaudio', 'audio/x-wav', 'audio/mp3'],
                iconCls: 'fa fa-file-audio-o',
                text: 'Audio'
            },
            {
                name: 'VIDEO',
                mimes: ['video/mpeg', 'video/mp4', 'video/quicktime', 'video/x-ms-wmv'],
                iconCls: 'fa fa-file-video-o',
                text: 'Video'
            },
            {
                name: 'ARCHIVE',
                mimes: ['application/zip'],
                iconCls: 'fa fa-file-archive-o',
                text: 'Archive'
            }
        ];
        this.fileUrl = '/api/files';
        const { foldersUrl, folderMoveUrl } = configuration.urls;
        this.folderUrls = { foldersUrl, folderMoveUrl };
        this.fileUrl = configuration.urls.filesUrl;
        this.isMultiSelection = configuration.isMultiSelection || false;
        this.maxFileSize = configuration.maxFileSize || 0;
        this.mimeTypes = configuration.mimeTypes || null;
        this.allowChooseMultipleFiles = configuration.allowChooseMultipleFiles || false;
    }
}
FileManagerConfiguration.decorators = [
    { type: Injectable }
];
/** @nocollapse */
FileManagerConfiguration.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: ['fileManagerConfiguration',] }] },
    { type: undefined, decorators: [{ type: Inject, args: [FILEMANAGER_TRANSLATION_TOKEN,] }] }
];
if (false) {
    /** @type {?} */
    FileManagerConfiguration.prototype.allowedCropSize;
    /** @type {?} */
    FileManagerConfiguration.prototype.contextMenuItems;
    /** @type {?} */
    FileManagerConfiguration.prototype.fileTypesFilter;
    /** @type {?} */
    FileManagerConfiguration.prototype.folderUrls;
    /** @type {?} */
    FileManagerConfiguration.prototype.fileUrl;
    /** @type {?} */
    FileManagerConfiguration.prototype.isMultiSelection;
    /** @type {?} */
    FileManagerConfiguration.prototype.maxFileSize;
    /** @type {?} */
    FileManagerConfiguration.prototype.mimeTypes;
    /** @type {?} */
    FileManagerConfiguration.prototype.allowChooseMultipleFiles;
    /** @type {?} */
    FileManagerConfiguration.prototype.filemanagerTranslations;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IFileManagerConfiguration() { }
if (false) {
    /** @type {?} */
    IFileManagerConfiguration.prototype.urls;
    /** @type {?|undefined} */
    IFileManagerConfiguration.prototype.isMultiSelection;
    /** @type {?|undefined} */
    IFileManagerConfiguration.prototype.maxFileSize;
    /** @type {?|undefined} */
    IFileManagerConfiguration.prototype.mimeTypes;
    /** @type {?} */
    IFileManagerConfiguration.prototype.allowChooseMultipleFiles;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class IUrlConfiguration {
}
if (false) {
    /** @type {?} */
    IUrlConfiguration.prototype.filesUrl;
    /** @type {?} */
    IUrlConfiguration.prototype.foldersUrl;
    /** @type {?} */
    IUrlConfiguration.prototype.folderMoveUrl;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TreeService extends NodeService {
    /**
     * @param {?} http
     * @param {?} configuration
     */
    constructor(http, configuration) {
        super(http);
        this.http = http;
        this.apiConfig = {
            addUrl: configuration.urls.foldersUrl,
            getUrl: configuration.urls.foldersUrl,
            updateUrl: configuration.urls.foldersUrl,
            removeUrl: configuration.urls.foldersUrl,
            moveUrl: configuration.urls.folderMoveUrl
        };
    }
}
TreeService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
TreeService.ctorParameters = () => [
    { type: HttpClient },
    { type: undefined, decorators: [{ type: Inject, args: ['fileManagerConfiguration',] }] }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    TreeService.prototype.http;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileModel {
    /**
     * @param {?} data
     */
    constructor(data) {
        this._iconsFolder = FileModel.smallIconsFolder;
        this.selected = false;
        this.fromJSON(data);
    }
    /**
     * @param {?} name
     * @return {?}
     */
    set name(name) {
        this._name = name;
    }
    /**
     * @return {?}
     */
    get name() {
        return this._name;
    }
    /**
     * @return {?}
     */
    get thumbnailUrl() {
        return this.isImage() ? this._orgData.thumbnailUrl : `${FileModel.smallIconsFolder}${this.getFileExt()}.png`;
    }
    /**
     * @return {?}
     */
    get url() {
        return this.isImage() ? this._orgData.url : `${FileModel.bigIconsFolder}${this.getFileExt()}.png`;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    fromJSON(data) {
        this._orgData = data;
        this.name = data.name;
        this.selected = data.selected || false;
    }
    /**
     * @return {?}
     */
    toJSON() {
        return this._orgData;
    }
    /**
     * @return {?}
     */
    getId() {
        return this._orgData.id;
    }
    /**
     * @return {?}
     */
    getHeight() {
        return this._orgData.height || 0;
    }
    /**
     * @return {?}
     */
    getFileExt() {
        return this.name.split('.').pop();
    }
    /**
     * @return {?}
     */
    getMime() {
        return this._orgData.type;
    }
    /**
     * @return {?}
     */
    getWidth() {
        return this._orgData.width || 0;
    }
    /**
     * @return {?}
     */
    isImage() {
        return ['image/jpg', 'image/jpeg', 'image/png', 'image/gif', 'image/png'].indexOf(this.getMime()) > -1;
    }
    /**
     * @return {?}
     */
    getSelectData() {
        return {
            id: this.getId(),
            name: this.name,
            url: this.url,
            width: this.getWidth(),
            height: this.getHeight(),
            mime: this.getMime()
        };
    }
}
FileModel.smallIconsFolder = '/icons/128px/';
FileModel.bigIconsFolder = '/icons/512px/';
if (false) {
    /** @type {?} */
    FileModel.smallIconsFolder;
    /** @type {?} */
    FileModel.bigIconsFolder;
    /**
     * @type {?}
     * @private
     */
    FileModel.prototype._orgData;
    /**
     * @type {?}
     * @private
     */
    FileModel.prototype._name;
    /**
     * @type {?}
     * @private
     */
    FileModel.prototype._iconsFolder;
    /** @type {?} */
    FileModel.prototype.selected;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const FileManagerActionTypes = {
    CHOOSE_FILES: 'FILEMANAGER_CHOOSE_FILES',
    CROP_FILE: 'FILEMANAGER_CROP_FILE',
    CROP_FILE_SUCCESS: 'FILEMANAGER_CROP_FILE_SUCCESS',
    CROP_FILE_ERROR: 'FILEMANAGER_CROP_FILE_ERROR',
    DELETE_FILE: 'FILEMANAGER_DELETE_FILE',
    DELETE_FILE_SUCCESS: 'FILEMANAGER_DELETE_FILE_SUCCESS',
    DELETE_FILE_SELECTION: 'FILEMANAGER_DELETE_FILE_SELECTION',
    DELETE_FILE_SELECTION_SUCCESS: 'FILEMANAGER_DELETE_FILE_SELECTION_SUCCESS',
    INVERSE_FILE_SELECTION: 'FILEMANAGER_INVERSE_FILE_SELECTION',
    LOAD_FILES: 'FILEMANAGER_LOAD_FILES',
    LOAD_FILES_SUCCESS: 'FILEMANAGER_LOAD_FILES_SUCCESS',
    MOVE_FILES_SUCCESS: 'FILEMANAGER_MOVE_FILES_SUCCESS',
    MOVE_FILES_ERROR: 'FILEMANAGER_MOVE_FILES_ERROR',
    SELECT_ALL: 'FILEMANAGER_SELECT_ALL',
    SELECT_FILE: 'FILEMANAGER_SELECT_FILE',
    UNSELECT_FILE: 'FILEMANAGER_UNSELECT_FILE',
    UNSELECT_ALL: 'FILEMANAGER_UNSELECT_ALL',
    UPLOAD_FILE: 'FILEMANAGER_UPLOAD_FILE',
    UPLOAD_FILE_ERROR: 'FILEMANAGER_UPLOAD_FILE_ERROR',
    UPLOAD_FILE_SUCCESS: 'FILEMANAGER_UPLOAD_FILE_SUCCESS',
};
class ChooseFilesAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.CHOOSE_FILES;
    }
}
if (false) {
    /** @type {?} */
    ChooseFilesAction.prototype.type;
    /** @type {?} */
    ChooseFilesAction.prototype.payload;
}
class CropFileAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.CROP_FILE;
    }
}
if (false) {
    /** @type {?} */
    CropFileAction.prototype.type;
    /** @type {?} */
    CropFileAction.prototype.payload;
}
class CropFileErrorAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.CROP_FILE_ERROR;
    }
}
if (false) {
    /** @type {?} */
    CropFileErrorAction.prototype.type;
    /** @type {?} */
    CropFileErrorAction.prototype.payload;
}
class CropFileSuccessAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.CROP_FILE_SUCCESS;
    }
}
if (false) {
    /** @type {?} */
    CropFileSuccessAction.prototype.type;
    /** @type {?} */
    CropFileSuccessAction.prototype.payload;
}
class DeleteFileAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.DELETE_FILE;
    }
}
if (false) {
    /** @type {?} */
    DeleteFileAction.prototype.type;
    /** @type {?} */
    DeleteFileAction.prototype.payload;
}
class DeleteFileSuccessAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.DELETE_FILE_SUCCESS;
    }
}
if (false) {
    /** @type {?} */
    DeleteFileSuccessAction.prototype.type;
    /** @type {?} */
    DeleteFileSuccessAction.prototype.payload;
}
class DeleteSelectedFilesAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.DELETE_FILE_SELECTION;
    }
}
if (false) {
    /** @type {?} */
    DeleteSelectedFilesAction.prototype.type;
    /** @type {?} */
    DeleteSelectedFilesAction.prototype.payload;
}
class DeleteSelectedFilesSuccessAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.DELETE_FILE_SELECTION_SUCCESS;
    }
}
if (false) {
    /** @type {?} */
    DeleteSelectedFilesSuccessAction.prototype.type;
    /** @type {?} */
    DeleteSelectedFilesSuccessAction.prototype.payload;
}
class InverseFilesSelectionAction {
    constructor() {
        this.type = FileManagerActionTypes.INVERSE_FILE_SELECTION;
    }
}
if (false) {
    /** @type {?} */
    InverseFilesSelectionAction.prototype.type;
}
class LoadFilesAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.LOAD_FILES;
    }
}
if (false) {
    /** @type {?} */
    LoadFilesAction.prototype.type;
    /** @type {?} */
    LoadFilesAction.prototype.payload;
}
class LoadFilesSuccessAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.LOAD_FILES_SUCCESS;
    }
}
if (false) {
    /** @type {?} */
    LoadFilesSuccessAction.prototype.type;
    /** @type {?} */
    LoadFilesSuccessAction.prototype.payload;
}
class MoveFilesErrorAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.MOVE_FILES_ERROR;
    }
}
if (false) {
    /** @type {?} */
    MoveFilesErrorAction.prototype.type;
    /** @type {?} */
    MoveFilesErrorAction.prototype.payload;
}
class MoveFilesSuccessAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.MOVE_FILES_SUCCESS;
    }
}
if (false) {
    /** @type {?} */
    MoveFilesSuccessAction.prototype.type;
    /** @type {?} */
    MoveFilesSuccessAction.prototype.payload;
}
class SelectAllFilesAction {
    constructor() {
        this.type = FileManagerActionTypes.SELECT_ALL;
    }
}
if (false) {
    /** @type {?} */
    SelectAllFilesAction.prototype.type;
}
class SelectFileAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.SELECT_FILE;
    }
}
if (false) {
    /** @type {?} */
    SelectFileAction.prototype.type;
    /** @type {?} */
    SelectFileAction.prototype.payload;
}
class UnSelectAllFilesAction {
    constructor() {
        this.type = FileManagerActionTypes.UNSELECT_ALL;
    }
}
if (false) {
    /** @type {?} */
    UnSelectAllFilesAction.prototype.type;
}
class UnSelectFileAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.UNSELECT_FILE;
    }
}
if (false) {
    /** @type {?} */
    UnSelectFileAction.prototype.type;
    /** @type {?} */
    UnSelectFileAction.prototype.payload;
}
class UploadFilesAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.UPLOAD_FILE;
    }
}
if (false) {
    /** @type {?} */
    UploadFilesAction.prototype.type;
    /** @type {?} */
    UploadFilesAction.prototype.payload;
}
class UploadFilesErrorAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.UPLOAD_FILE_ERROR;
    }
}
if (false) {
    /** @type {?} */
    UploadFilesErrorAction.prototype.type;
    /** @type {?} */
    UploadFilesErrorAction.prototype.payload;
}
class UploadFilesSuccessAction {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = FileManagerActionTypes.UPLOAD_FILE_SUCCESS;
    }
}
if (false) {
    /** @type {?} */
    UploadFilesSuccessAction.prototype.type;
    /** @type {?} */
    UploadFilesSuccessAction.prototype.payload;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CropComponent {
    /**
     * @param {?} resolver
     * @param {?} configuration
     * @param {?} store
     * @param {?} filemanagerTranslations
     */
    constructor(resolver, configuration, store, filemanagerTranslations) {
        this.resolver = resolver;
        this.configuration = configuration;
        this.store = store;
        this.filemanagerTranslations = filemanagerTranslations;
        this.onCrop = new EventEmitter();
        this.cropSizeList = configuration.allowedCropSize;
    }
    /**
     * @param {?} cropSize
     * @return {?}
     */
    updateCropSize(cropSize) {
        /** @type {?} */
        const image = new Image();
        /** @type {?} */
        const cropperComponent = this.resolver.resolveComponentFactory(ImageCropperComponent);
        /** @type {?} */
        const cropperComponentRef = this.container.createComponent(cropperComponent);
        if (this.container.length > 1) {
            this.container.detach(0);
        }
        this.currentCropSize = cropSize;
        cropperComponentRef.instance.settings = this.getCropperSettings();
        cropperComponentRef.instance.image = {};
        cropperComponentRef.instance.onCrop
            .subscribe((/**
         * @param {?} bounds
         * @return {?}
         */
        (bounds) => this.bounds = bounds));
        setTimeout((/**
         * @return {?}
         */
        () => {
            image.src = this.file.url;
            cropperComponentRef.instance.setImage(image);
        }));
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this.updateCropSize(this.cropSizeList[0]);
    }
    /**
     * @return {?}
     */
    cropImage() {
        /** @type {?} */
        const bounds = {
            x: this.bounds.left,
            y: this.bounds.top,
            width: this.bounds.width,
            height: this.bounds.height
        };
        this.store.dispatch(new CropFileAction({ file: this.file, bounds }));
    }
    /**
     * @private
     * @return {?}
     */
    getCropperSettings() {
        /** @type {?} */
        const cropperSettings = new CropperSettings();
        /** @type {?} */
        const scale = this.calculateScale();
        /** @type {?} */
        const width = scale * this.file.getWidth();
        /** @type {?} */
        const height = scale * this.file.getHeight();
        cropperSettings.noFileInput = true;
        cropperSettings.width = this.currentCropSize.width;
        cropperSettings.height = this.currentCropSize.height;
        cropperSettings.canvasWidth = width;
        cropperSettings.canvasHeight = height;
        return cropperSettings;
    }
    /**
     * Calculates scale between current file dimensions and box 600x600
     * @private
     * @return {?}
     */
    calculateScale() {
        /** @type {?} */
        const scale = this.file.getWidth() / this.file.getHeight();
        if (scale > 1) {
            if (this.file.getWidth() > 600) {
                return 600 / this.file.getWidth();
            }
        }
        else {
            if (this.file.getHeight() > 600) {
                return 600 / this.file.getHeight();
            }
        }
        return 1;
    }
}
CropComponent.decorators = [
    { type: Component, args: [{
                selector: 'crop-image',
                template: `
      <div class="crop-image">
          <div class="crop-workbench">
              <div #container></div>
          </div>
          <div class="btn-toolbar">
              <div class="btn-group">
                  <button class="btn btn-primary" *ngFor="let cropSize of cropSizeList" (click)="updateCropSize(cropSize)"
                          [ngClass]="{'active': cropSize == currentCropSize}">{{cropSize.name}}
                  </button>
              </div>
              <div class="btn-group pull-right">
                  <button class="btn btn-success btn-icon" (click)="cropImage()">
                      <i class="fa fa-check"></i>
                      <span>{{ filemanagerTranslations.RI_FM_BTN_SAVE }}</span>
                  </button>
              </div>
          </div>
      </div>
  `,
                styles: [".btn-toolbar{margin:5px 0}.btn-toolbar .btn-group{margin:0}.crop-workbench{width:600px;height:400px;text-align:center}"]
            }] }
];
/** @nocollapse */
CropComponent.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: FileManagerConfiguration },
    { type: Store },
    { type: undefined, decorators: [{ type: Inject, args: [FILEMANAGER_TRANSLATION_TOKEN,] }] }
];
CropComponent.propDecorators = {
    file: [{ type: Input }],
    onCrop: [{ type: Output }],
    container: [{ type: ViewChild, args: ['container', { read: ViewContainerRef, static: true },] }],
    cropper: [{ type: ViewChild, args: ['cropper', { static: false },] }]
};
if (false) {
    /** @type {?} */
    CropComponent.prototype.file;
    /** @type {?} */
    CropComponent.prototype.onCrop;
    /** @type {?} */
    CropComponent.prototype.container;
    /** @type {?} */
    CropComponent.prototype.cropper;
    /**
     * @type {?}
     * @private
     */
    CropComponent.prototype.bounds;
    /** @type {?} */
    CropComponent.prototype.cropSizeList;
    /** @type {?} */
    CropComponent.prototype.currentCropSize;
    /**
     * @type {?}
     * @private
     */
    CropComponent.prototype.resolver;
    /**
     * @type {?}
     * @private
     */
    CropComponent.prototype.configuration;
    /**
     * @type {?}
     * @private
     */
    CropComponent.prototype.store;
    /** @type {?} */
    CropComponent.prototype.filemanagerTranslations;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function ICropBounds() { }
if (false) {
    /** @type {?} */
    ICropBounds.prototype.x;
    /** @type {?} */
    ICropBounds.prototype.y;
    /** @type {?} */
    ICropBounds.prototype.width;
    /** @type {?} */
    ICropBounds.prototype.height;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function ICropSize() { }
if (false) {
    /** @type {?} */
    ICropSize.prototype.name;
    /** @type {?} */
    ICropSize.prototype.width;
    /** @type {?} */
    ICropSize.prototype.height;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DropdownComponent {
    constructor() {
        this.onClick = new EventEmitter();
        this.isOpen = false;
    }
    /**
     * @return {?}
     */
    hide() {
        this.isOpen = false;
    }
    /**
     * @param {?} button
     * @return {?}
     */
    selectButton(button) {
        this.hide();
        this.onClick.emit(button);
    }
    /**
     * @return {?}
     */
    toggleOpen() {
        this.isOpen = !this.isOpen;
    }
}
DropdownComponent.decorators = [
    { type: Component, args: [{
                selector: 'ri-dropdown',
                template: "<div class=\"btn-group dropdown\" [ngClass]=\"{'show': isOpen}\">\n  <button class=\"btn btn-secondary\" [ngClass]=\"{disabled: mainButton.disabled}\" (click)=\"selectButton(mainButton)\">\n    <span *ngIf=\"displayMainButtonLabel\">{{mainButton.name}}</span>\n    <i *ngIf=\"mainButton.icon\" class=\"{{mainButton.iconCssClass}}\"></i>\n  </button><!--\n  -->\n  <button class=\"btn btn-secondary dropdown-toggle dropdown-toggle-split\" id=\"dropdownMenuButton\"\n          [ngClass]=\"{disabled: mainButton.disabled}\"\n          (click)=\"toggleOpen()\">\n    <span class=\"caret\"></span>\n  </button>\n  <ul class=\"dropdown-menu\" role=\"menu\" aria-labelledby=\"single-button\" (mouseleave)=\"hide()\"\n      [ngClass]=\"{'show': isOpen}\">\n    <li class=\"\"\n        [ngClass]=\"{'dropdown-divider': button.isDivider(), 'dropdown-item': !button.isDivider(), disabled: button.disabled}\"\n        *ngFor=\"let button of buttons \" (click)=\"selectButton(button)\">\n      <span *ngIf=\"button.icon\" class=\"{{button.iconCssClass}}\"></span>\n      <span *ngIf=\"button.label\">{{button.name}}</span>\n    </li>\n  </ul>\n</div>\n",
                styles: [".dropdown{display:inline-block;height:34px}.dropdown .btn{height:34px}.dropdown li{cursor:pointer}.dropdown li:hover:not(.disabled){background:rgba(0,123,255,.45)}"]
            }] }
];
DropdownComponent.propDecorators = {
    mainButton: [{ type: Input }],
    buttons: [{ type: Input }],
    displayMainButtonLabel: [{ type: Input }],
    onClick: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    DropdownComponent.prototype.mainButton;
    /** @type {?} */
    DropdownComponent.prototype.buttons;
    /** @type {?} */
    DropdownComponent.prototype.displayMainButtonLabel;
    /** @type {?} */
    DropdownComponent.prototype.onClick;
    /** @type {?} */
    DropdownComponent.prototype.isOpen;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IFileDataProperties() { }
if (false) {
    /** @type {?} */
    IFileDataProperties.prototype.id;
    /** @type {?} */
    IFileDataProperties.prototype.folderId;
    /** @type {?} */
    IFileDataProperties.prototype.name;
    /** @type {?} */
    IFileDataProperties.prototype.size;
    /** @type {?} */
    IFileDataProperties.prototype.data;
    /** @type {?} */
    IFileDataProperties.prototype.type;
    /** @type {?|undefined} */
    IFileDataProperties.prototype.width;
    /** @type {?|undefined} */
    IFileDataProperties.prototype.height;
    /** @type {?|undefined} */
    IFileDataProperties.prototype.selected;
}
/**
 * @record
 */
function IImageDimensions() { }
if (false) {
    /** @type {?} */
    IImageDimensions.prototype.width;
    /** @type {?} */
    IImageDimensions.prototype.height;
}
class ImageDataConverter {
    /**
     * @param {?} file
     * @param {?} folderId
     * @return {?}
     */
    getProperties(file, folderId) {
        /** @type {?} */
        const properties = {
            id: UUID.UUID(),
            folderId: folderId,
            name: file.name,
            size: file.size,
            type: file.type,
            data: ''
        };
        /** @type {?} */
        const reader = this.getBase64FromFile(file);
        return reader
            .pipe(concatMap((/**
         * @param {?} data
         * @return {?}
         */
        (data) => {
            properties.data = data;
            if (properties.type.indexOf('image') === 0) {
                return this.getImageDimensions(data);
            }
            else {
                return of({ width: 0, height: 0 });
            }
        })), map((/**
         * @param {?} dimensions
         * @return {?}
         */
        (dimensions) => {
            properties.width = dimensions.width;
            properties.height = dimensions.height;
            return properties;
        })));
    }
    /**
     * Create observable which return image as base64 data
     * @private
     * @param {?} file
     * @return {?}
     */
    getBase64FromFile(file) {
        /** @type {?} */
        const reader = new FileReader();
        reader.readAsDataURL(file);
        return fromEvent(reader, 'load')
            .pipe(map((/**
         * @return {?}
         */
        () => {
            return reader.result.toString();
        })));
    }
    /**
     * Create observable which return dimensions of the image
     * @private
     * @param {?} data
     * @return {?}
     */
    getImageDimensions(data) {
        /** @type {?} */
        const image = new Image();
        image.src = data;
        image.style.display = 'none';
        /** @type {?} */
        const loadImage = fromEvent(image, 'load')
            .pipe(map((/**
         * @return {?}
         */
        () => {
            return {
                width: image.naturalWidth,
                height: image.naturalHeight
            };
        })));
        document.body.appendChild(image);
        return loadImage;
    }
}
ImageDataConverter.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ExtendedFileUploader extends FileUploader {
    /**
     * @param {?} options
     * @param {?} filemanagerNotification
     */
    constructor(options, filemanagerNotification) {
        super(options);
        this.filemanagerNotification = filemanagerNotification;
    }
    /**
     * @param {?} item
     * @param {?} filter
     * @param {?} options
     * @return {?}
     */
    onWhenAddingFileFailed(item, filter, options) {
        /** @type {?} */
        const notification = {
            type: 'alert',
            title: 'Add file to queue',
            message: `File not add to queue`
        };
        if (filter.name === 'fileSize') {
            notification.message = `File size is too large - max size  is ${options.maxFileSize / 1024} KB`;
        }
        else {
            notification.message = `File mime type "${item.type}" is not allowed`;
        }
        this.filemanagerNotification.send(notification);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    uploadItem(value) {
        if (this.options.url) {
            super.uploadItem(value);
        }
        else {
            /** @type {?} */
            const imageDataConverter = new ImageDataConverter();
            this._onProgressItem(value, 0);
            if (this.isUploading) {
                return;
            }
            this.isUploading = true;
            /** @type {?} */
            const header = this.options.headers.find((/**
             * @param {?} object
             * @return {?}
             */
            (object) => object.name === 'folderId'));
            this._onProgressItem(value, 50);
            imageDataConverter.getProperties(value._file, header.value)
                .subscribe((/**
             * @param {?} file
             * @return {?}
             */
            (file) => {
                this.isUploading = false;
                this._onProgressItem(value, 100);
                this._onCompleteItem(value, JSON.stringify(file), 200, {});
            }));
        }
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    ExtendedFileUploader.prototype.filemanagerNotification;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FilemanagerNotifications {
    constructor() {
        this._notification$ = new Subject();
        this.notification$ = this._notification$.asObservable();
    }
    /**
     * @param {?} notification
     * @return {?}
     */
    send(notification) {
        this._notification$.next(notification);
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    FilemanagerNotifications.prototype._notification$;
    /** @type {?} */
    FilemanagerNotifications.prototype.notification$;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileManagerUploader {
    /**
     * @param {?} configuration
     * @param {?} filemanagerNotification
     */
    constructor(configuration, filemanagerNotification) {
        /** @type {?} */
        const options = {
            allowedMimeType: configuration.mimeTypes,
            url: configuration.urls.filesUrl,
            maxFileSize: configuration.maxFileSize
        };
        this.uploader = new ExtendedFileUploader(options, filemanagerNotification);
    }
    /**
     * @return {?}
     */
    clear() {
        this.uploader.authToken = null;
        this.uploader.setOptions(this.getDefaultOptions());
    }
    /**
     * @return {?}
     */
    getDefaultOptions() {
        /** @type {?} */
        const options = {};
        options['removeAfterUpload'] = true;
        options['autoUpload'] = true;
        options['method'] = 'POST';
        return options;
    }
    /**
     * @param {?} token
     * @return {?}
     */
    setAuthorizationToken(token) {
        this.uploader.authToken = token;
    }
    /**
     * @param {?} directoryId
     * @return {?}
     */
    setDirectoryId(directoryId) {
        /** @type {?} */
        const options = this.getDefaultOptions();
        options['headers'] = [{ name: 'folderId', value: directoryId.toString() }];
        this.uploader.setOptions(options);
        return this;
    }
}
FileManagerUploader.decorators = [
    { type: Injectable }
];
/** @nocollapse */
FileManagerUploader.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: ['fileManagerConfiguration',] }] },
    { type: FilemanagerNotifications }
];
if (false) {
    /** @type {?} */
    FileManagerUploader.prototype.uploader;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileComponent {
    /**
     * @param {?} configuration
     * @param {?} store
     * @param {?} filemanagerTranslations
     */
    constructor(configuration, store, filemanagerTranslations) {
        this.configuration = configuration;
        this.store = store;
        this.filemanagerTranslations = filemanagerTranslations;
        this.onPreviewFile = new EventEmitter();
        this.onCropFile = new EventEmitter();
        this.onSelectFile = new EventEmitter();
    }
    /**
     * Fired when clicked on button "delete file"
     * @param {?} $event
     * @param {?} file
     * @return {?}
     */
    deleteFile($event, file) {
        this.store.dispatch(new DeleteFileAction({ file }));
        $event.preventDefault();
        $event.stopPropagation();
    }
    /**
     * @param {?} file
     * @return {?}
     */
    getRemoveMessage(file) {
        return this.filemanagerTranslations.RI_FM_MSG_REMOVE_QUESTION.replace('${FILENAME}', file.name);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    openPreview($event) {
        /** @type {?} */
        const fileEvent = {
            eventName: 'onPreviewFile',
            file: this.file
        };
        this.onPreviewFile.emit(fileEvent);
        $event.preventDefault();
        $event.stopPropagation();
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    openCrop($event) {
        /** @type {?} */
        const fileEvent = {
            eventName: 'onCropFile',
            file: this.file
        };
        this.onCropFile.emit(fileEvent);
        $event.preventDefault();
        $event.stopPropagation();
    }
    /**
     * @return {?}
     */
    selectFile() {
        this.store.dispatch(new SelectFileAction({ file: this.file }));
    }
    /**
     * @return {?}
     */
    unSelectFile() {
        this.store.dispatch(new UnSelectFileAction({ file: this.file }));
    }
    /**
     * @param {?} $event
     * @param {?} file
     * @return {?}
     */
    chooseFile($event, file) {
        this.store.dispatch(new ChooseFilesAction({ files: [file.toJSON()] }));
        $event.preventDefault();
        $event.stopPropagation();
    }
}
FileComponent.decorators = [
    { type: Component, args: [{
                selector: 'ri-file-component',
                template: "<div *ngIf=\"configuration.isMultiSelection\" class=\"file-selection-input\">\n  <i class=\"fa fa-2x checked fa-check-square-o\" (click)=\"unSelectFile()\"></i>\n  <i class=\"fa fa-2x unchecked fa-square-o\" (click)=\"selectFile()\"></i>\n</div>\n<div class=\"rounded file-img\" [ngClass]=\"{'file-img-symbol': !file.isImage()}\"\n     [style.background-image]=\"'url(' + file.thumbnailUrl + ')'\"></div>\n<span class=\"file-name\">{{file.name}}</span>\n<div class=\"file-menu\">\n  <div class=\"btn-group btn-group-sm\">\n    <button mwlConfirmationPopover\n            [popoverTitle]=\"filemanagerTranslations.RI_FM_LBL_REMOVE_TITLE\"\n            [popoverMessage]=\"getRemoveMessage(file)\"\n            [appendToBody]=\"true\"\n            [confirmText]=\"filemanagerTranslations.RI_FM_BTN_DELETE_YES\"\n            [cancelText]=\"filemanagerTranslations.RI_FM_BTN_DELETE_NO\"\n            placement=\"bottom\"\n            (confirm)=\"deleteFile($event.clickEvent, file)\"\n            class=\"btn btn-sm btn-danger btn-icon\">\n      <i class=\"fa fa-trash\"></i>\n    </button>\n    <button (click)=\"openPreview($event)\" class=\"btn btn-sm btn-secondary btn-icon\">\n      <i class=\"fa fa-search\"></i>\n    </button>\n    <button *ngIf=\"file.isImage()\" (click)=\"openCrop($event)\" class=\"btn btn-sm btn-secondary btn-icon\">\n      <i class=\"fa fa-crop\"></i>\n    </button>\n    <button *ngIf=\"file.isImage()\" (click)=\"chooseFile($event, file)\" class=\"btn btn-sm btn-primary btn-icon\">\n      <i class=\"fa fa-image\"></i>\n    </button>\n  </div>\n</div>\n",
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
FileComponent.ctorParameters = () => [
    { type: FileManagerConfiguration },
    { type: Store },
    { type: undefined, decorators: [{ type: Inject, args: [FILEMANAGER_TRANSLATION_TOKEN,] }] }
];
FileComponent.propDecorators = {
    file: [{ type: Input }],
    onPreviewFile: [{ type: Output }],
    onCropFile: [{ type: Output }],
    onSelectFile: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    FileComponent.prototype.file;
    /** @type {?} */
    FileComponent.prototype.onPreviewFile;
    /** @type {?} */
    FileComponent.prototype.onCropFile;
    /** @type {?} */
    FileComponent.prototype.onSelectFile;
    /** @type {?} */
    FileComponent.prototype.configuration;
    /**
     * @type {?}
     * @private
     */
    FileComponent.prototype.store;
    /** @type {?} */
    FileComponent.prototype.filemanagerTranslations;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function ISelectFile() { }
if (false) {
    /** @type {?} */
    ISelectFile.prototype.id;
    /** @type {?} */
    ISelectFile.prototype.name;
    /** @type {?} */
    ISelectFile.prototype.url;
    /** @type {?} */
    ISelectFile.prototype.width;
    /** @type {?} */
    ISelectFile.prototype.height;
    /** @type {?} */
    ISelectFile.prototype.mime;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IOuterFile() { }
if (false) {
    /** @type {?} */
    IOuterFile.prototype.id;
    /** @type {?|undefined} */
    IOuterFile.prototype.folderId;
    /** @type {?} */
    IOuterFile.prototype.name;
    /** @type {?} */
    IOuterFile.prototype.thumbnailUrl;
    /** @type {?} */
    IOuterFile.prototype.url;
    /** @type {?} */
    IOuterFile.prototype.width;
    /** @type {?} */
    IOuterFile.prototype.height;
    /** @type {?} */
    IOuterFile.prototype.type;
    /** @type {?|undefined} */
    IOuterFile.prototype.data;
    /** @type {?|undefined} */
    IOuterFile.prototype.size;
    /** @type {?|undefined} */
    IOuterFile.prototype.selected;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const FILEMANAGER_TREE_NAME = 'fileManagerTree';
/**
 * @abstract
 */
class AbstractFileManagerApiService {
    constructor() {
        this.treeName = FILEMANAGER_TREE_NAME;
        this.fileManagerName = 'fileManagerFiles';
        this.currentNodeId = '';
    }
}
if (false) {
    /**
     * @type {?}
     * @protected
     */
    AbstractFileManagerApiService.prototype.treeName;
    /**
     * @type {?}
     * @protected
     */
    AbstractFileManagerApiService.prototype.fileManagerName;
    /**
     * @type {?}
     * @protected
     */
    AbstractFileManagerApiService.prototype.nodes;
    /**
     * @type {?}
     * @protected
     */
    AbstractFileManagerApiService.prototype.files;
    /**
     * @type {?}
     * @protected
     */
    AbstractFileManagerApiService.prototype.currentNodeId;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FilesListComponent {
    /**
     * @param {?} configuration
     * @param {?} store
     */
    constructor(configuration, store) {
        this.configuration = configuration;
        this.store = store;
        this.onPreviewFile = new EventEmitter();
        this.onCropFile = new EventEmitter();
        this.onSelectFile = new EventEmitter();
        this.removeTitle = 'Remove file';
        this.dragZone = FILEMANAGER_TREE_NAME;
    }
    /**
     * Fired when clicked on button "delete file"
     * @param {?} file
     * @return {?}
     */
    deleteFile(file) {
        this.store.dispatch(new DeleteFileAction({ file }));
    }
    /**
     * @param {?} fileEvent
     * @return {?}
     */
    openPreview(fileEvent) {
        this.onPreviewFile.emit(fileEvent);
    }
    /**
     * @param {?} fileEvent
     * @return {?}
     */
    openCrop(fileEvent) {
        this.onCropFile.emit(fileEvent);
    }
    /**
     * @param {?} file
     * @return {?}
     */
    toggleSelection(file) {
        if (file.selected) {
            this.store.dispatch(new UnSelectFileAction({ file }));
        }
        else {
            this.store.dispatch(new SelectFileAction({ file }));
        }
    }
    /**
     * @param {?} file
     * @return {?}
     */
    isSelected(file) {
        return this.selectedFiles.indexOf(file.getId().toString()) > -1;
    }
}
FilesListComponent.decorators = [
    { type: Component, args: [{
                selector: 'ri-files-list',
                template: "<div class=\"files-list\">\n  <div class=\"file\" *ngFor=\"let file of files\" [ngClass]=\"{'selected': isSelected(file)}\"  riDraggable [data]=\"file.toJSON()\" [sourceType]=\"'FILE'\" [dragZone]=\"dragZone\">\n    <ri-file-component [file]=\"file\" (onPreviewFile)=\"openPreview($event)\" (onCropFile)=\"openCrop($event)\"></ri-file-component>\n  </div>\n</div>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                styles: [".files-list .file{display:inline-block;position:relative;cursor:pointer;text-align:center;width:140px;height:110px;padding:5px;border:1px solid #ccc;background-color:#eee;border-radius:10px;margin:0 0 20px 20px}.files-list .file .file-img{width:128px;height:98px;background-size:cover;background-repeat:no-repeat}.files-list .file .file-img.file-img-symbol{background-size:contain;background-position-x:50%}.files-list .file .file-name{display:none;position:absolute;bottom:0;left:0;right:0;text-align:center;background-color:rgba(238,238,238,.5)}.files-list .file .file-menu{display:none;position:absolute;top:30%;left:0;right:0;text-align:center}.files-list .file .file-selection-input{display:none;position:absolute;top:3px;left:3px;cursor:pointer;z-index:10}.files-list .file .file-selection-input .checked{display:none}.files-list .file .file-selection-input .unchecked{display:block}.files-list .file:hover .file-img{opacity:.3}.files-list .file:hover .file-menu,.files-list .file:hover .file-name,.files-list .file:hover .file-selection-input{display:block}.files-list .file.selected{border-color:#fff33a;background-color:rgba(255,243,58,.5)}.files-list .file.selected .file-name{background-color:rgba(255,243,58,.5)}.files-list .file.selected .file-menu,.files-list .file.selected .file-selection-input{display:none}.files-list .file.selected .file-selection-input .checked{display:block}.files-list .file.selected .file-selection-input .unchecked{display:none}.files-list .file.selected:hover .file-selection-input{display:block}"]
            }] }
];
/** @nocollapse */
FilesListComponent.ctorParameters = () => [
    { type: FileManagerConfiguration },
    { type: Store }
];
FilesListComponent.propDecorators = {
    files: [{ type: Input }],
    selectedFiles: [{ type: Input }],
    onPreviewFile: [{ type: Output }],
    onCropFile: [{ type: Output }],
    onSelectFile: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    FilesListComponent.prototype.files;
    /** @type {?} */
    FilesListComponent.prototype.selectedFiles;
    /** @type {?} */
    FilesListComponent.prototype.onPreviewFile;
    /** @type {?} */
    FilesListComponent.prototype.onCropFile;
    /** @type {?} */
    FilesListComponent.prototype.onSelectFile;
    /** @type {?} */
    FilesListComponent.prototype.removeTitle;
    /** @type {?} */
    FilesListComponent.prototype.dragZone;
    /** @type {?} */
    FilesListComponent.prototype.configuration;
    /**
     * @type {?}
     * @private
     */
    FilesListComponent.prototype.store;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function INotification() { }
if (false) {
    /** @type {?} */
    INotification.prototype.type;
    /** @type {?} */
    INotification.prototype.title;
    /** @type {?|undefined} */
    INotification.prototype.message;
}
/**
 * @record
 */
function INotificationService() { }
if (false) {
    /** @type {?} */
    INotificationService.prototype.notification$;
    /**
     * @param {?} notification
     * @return {?}
     */
    INotificationService.prototype.send = function (notification) { };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IFilemanagerTranslation() { }
if (false) {
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_BTN_LANDSCAPE;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_BTN_PORTRAIT;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_BTN_SAVE;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_BTN_DELETE_YES;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_BTN_DELETE_NO;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_LBL_CHOOSE_SELECTION;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_LBL_DELETE_SELECTION;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_LBL_INVERSE_SELECTION;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_LBL_REMOVE_TITLE;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_LBL_SEARCH_FOR;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_LBL_SELECT_ALL;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_LBL_UNSELECT_ALL;
    /** @type {?} */
    IFilemanagerTranslation.prototype.RI_FM_MSG_REMOVE_QUESTION;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PreviewComponent {
    constructor() {
        /**
         * Current index
         */
        this.currentIndex = 0;
        this.length = 0;
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        this.length = this.files.length;
        /** @type {?} */
        const selectedFiles = this.files
            .filter((/**
         * @param {?} file
         * @return {?}
         */
        (file) => file.getId() === this.file.getId()));
        this.currentIndex = selectedFiles.length === 1 ? this.files.indexOf(selectedFiles[0]) : -1;
    }
    /**
     * @return {?}
     */
    next() {
        if (this.currentIndex < this.length - 1) {
            this.currentIndex++;
        }
    }
    /**
     * @return {?}
     */
    prev() {
        if (this.currentIndex > 0) {
            this.currentIndex--;
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    keyEvent(event) {
        if (event.keyCode === 37 || event.keyCode === 74) {
            this.prev();
        }
        if (event.keyCode === 39 || event.keyCode === 75) {
            this.next();
        }
    }
}
PreviewComponent.decorators = [
    { type: Component, args: [{
                selector: 'ri-file-preview',
                template: "<div class=\"filemanager-preview\">\n  <div class=\"carousel slide\">\n    <div class=\"carousel-inner\" role=\"listbox\">\n      <div class=\"carousel-item\" *ngFor=\"let file of files; let i = index;\" [ngClass]=\"{'active': i == currentIndex}\">\n        <img src=\"{{file.url}}\" alt=\"{{file.name}}\" style=\"margin: 0 auto; display: block;\">\n        <div class=\"carousel-caption\">{{file.name}}</div>\n      </div>\n    </div>\n    <a class=\"left carousel-control-prev\" role=\"button\" (click)=\"prev()\" *ngIf=\"currentIndex != 0\">\n      <span class=\"fa fa-3x fa-chevron-left\" aria-hidden=\"true\"></span>\n    </a>\n    <a class=\"right carousel-control-next\" role=\"button\" (click)=\"next()\" *ngIf=\"currentIndex + 1 < length\">\n      <span class=\"fa fa-3x fa-chevron-right\" aria-hidden=\"true\"></span>\n    </a>\n  </div>\n</div>\n"
            }] }
];
PreviewComponent.propDecorators = {
    files: [{ type: Input }],
    file: [{ type: Input }],
    keyEvent: [{ type: HostListener, args: ['window:keydown', ['$event'],] }]
};
if (false) {
    /**
     * Collection of files
     * @type {?}
     */
    PreviewComponent.prototype.files;
    /**
     * Current viewed file
     * @type {?}
     */
    PreviewComponent.prototype.file;
    /**
     * Current index
     * @type {?}
     */
    PreviewComponent.prototype.currentIndex;
    /** @type {?} */
    PreviewComponent.prototype.length;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SearchFilterService {
    constructor() {
        /**
         * File type filter
         */
        this.filter$ = new BehaviorSubject('');
    }
    /**
     * @return {?}
     */
    getValue() {
        return this.filter$.getValue();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setValue(value) {
        this.filter$.next(value);
    }
}
SearchFilterService.decorators = [
    { type: Injectable }
];
if (false) {
    /**
     * File type filter
     * @type {?}
     */
    SearchFilterService.prototype.filter$;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileTypeFilterService {
    constructor() {
        /**
         * File type filter
         */
        this.filter$ = new BehaviorSubject(null);
    }
    /**
     * @return {?}
     */
    getValue() {
        return this.filter$.getValue();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setValue(value) {
        this.filter$.next(value);
    }
}
FileTypeFilterService.decorators = [
    { type: Injectable }
];
if (false) {
    /**
     * File type filter
     * @type {?}
     */
    FileTypeFilterService.prototype.filter$;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function StoreEntities() { }
/**
 * @record
 */
function IFileManagerState() { }
if (false) {
    /** @type {?} */
    IFileManagerState.prototype.entities;
    /** @type {?} */
    IFileManagerState.prototype.files;
    /** @type {?} */
    IFileManagerState.prototype.selectedFiles;
}
/**
 * @param {?} state
 * @param {?} action
 * @return {?}
 */
function cropFile(state, action) {
    /** @type {?} */
    const file = action.payload.file;
    /** @type {?} */
    const id = file.getId().toString();
    state.entities[id] = (/** @type {?} */ (Object.assign({}, file.toJSON())));
    return {
        entities: state.entities,
        files: state.files,
        selectedFiles: state.selectedFiles
    };
}
/**
 * @param {?} state
 * @return {?}
 */
function inverseFilesSelection(state) {
    return {
        entities: state.entities,
        files: state.files,
        selectedFiles: state.files.filter((/**
         * @param {?} i
         * @return {?}
         */
        (i) => state.selectedFiles.indexOf(i) === -1))
    };
}
/**
 * @param {?} state
 * @param {?} action
 * @return {?}
 */
function loadFiles(state, action) {
    /** @type {?} */
    const entities = {};
    /** @type {?} */
    const files = [];
    action.payload.files.map((/**
     * @param {?} file
     * @return {?}
     */
    (file) => {
        /** @type {?} */
        const id = file.id.toString();
        entities[id] = file;
        files.push(id);
    }));
    return {
        entities: entities,
        files: files,
        selectedFiles: []
    };
}
/**
 * @param {?} state
 * @param {?} action
 * @return {?}
 */
function moveFiles(state, action) {
    /** @type {?} */
    const files = action.payload.files;
    /** @type {?} */
    const ids = files.map((/**
     * @param {?} file
     * @return {?}
     */
    file => file.id.toString()));
    /** @type {?} */
    const folderId = action.payload.folderId ? action.payload.folderId.toString() : '';
    /** @type {?} */
    const entities = Object.assign({}, state.entities);
    ids.forEach((/**
     * @param {?} id
     * @return {?}
     */
    (id) => {
        /** @type {?} */
        const oldEntity = Object.assign({}, entities[id]);
        oldEntity.folderId = folderId;
        entities[id] = oldEntity;
    }));
    return {
        entities: entities,
        files: state.files.filter((/**
         * @param {?} i
         * @return {?}
         */
        (i) => ids.indexOf(i) === -1)),
        selectedFiles: state.selectedFiles.filter((/**
         * @param {?} i
         * @return {?}
         */
        (i) => ids.indexOf(i) === -1))
    };
}
/**
 * @param {?} state
 * @param {?} action
 * @return {?}
 */
function removeFile(state, action) {
    /** @type {?} */
    const id = action.payload.file.getId();
    delete state.entities[id];
    return {
        entities: state.entities,
        files: state.files.filter((/**
         * @param {?} i
         * @return {?}
         */
        (i) => i !== id)),
        selectedFiles: state.selectedFiles
    };
}
/**
 * @param {?} state
 * @return {?}
 */
function removeSelectedFiles(state) {
    /** @type {?} */
    const files = state.files.filter((/**
     * @param {?} i
     * @return {?}
     */
    (i) => state.selectedFiles.indexOf(i) === -1));
    /** @type {?} */
    const entities = {};
    files.forEach((/**
     * @param {?} fileId
     * @return {?}
     */
    (fileId) => {
        entities[fileId] = state.entities[fileId];
    }));
    return {
        entities: entities,
        files: files,
        selectedFiles: []
    };
}
/**
 * @param {?} state
 * @param {?} action
 * @return {?}
 */
function selectFile(state, action) {
    return {
        entities: state.entities,
        files: state.files,
        selectedFiles: [...state.selectedFiles, action.payload.file.getId().toString()]
    };
}
/**
 * @param {?} state
 * @return {?}
 */
function selectAllFiles(state) {
    return {
        entities: state.entities,
        files: state.files,
        selectedFiles: [...state.files]
    };
}
/**
 * @param {?} state
 * @param {?} action
 * @return {?}
 */
function uploadFiles(state, action) {
    /** @type {?} */
    const newState = {
        entities: Object.assign({}, state.entities),
        files: [...state.files],
        selectedFiles: []
    };
    action.payload.files.forEach((/**
     * @param {?} file
     * @return {?}
     */
    (file) => {
        /** @type {?} */
        const id = file.id.toString();
        newState.entities[id] = file;
        newState.files.push(id);
    }));
    return newState;
}
/**
 * @param {?} state
 * @return {?}
 */
function unSelectAllFiles(state) {
    return {
        entities: state.entities,
        files: state.files,
        selectedFiles: []
    };
}
/**
 * @param {?} state
 * @param {?} action
 * @return {?}
 */
function unSelectFile(state, action) {
    /** @type {?} */
    const fileId = action.payload.file.getId().toString();
    return {
        entities: state.entities,
        files: state.files,
        selectedFiles: state.selectedFiles.filter((/**
         * @param {?} id
         * @return {?}
         */
        (id) => id !== fileId))
    };
}
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function fileManagerReducer(state = {
    entities: {},
    files: [],
    selectedFiles: []
}, action) {
    switch (action.type) {
        case FileManagerActionTypes.CROP_FILE_SUCCESS:
            return cropFile(state, action);
        case FileManagerActionTypes.INVERSE_FILE_SELECTION:
            return inverseFilesSelection(state);
        case FileManagerActionTypes.DELETE_FILE_SELECTION_SUCCESS:
            return removeSelectedFiles(state);
        case FileManagerActionTypes.DELETE_FILE_SUCCESS:
            return removeFile(state, action);
        case FileManagerActionTypes.MOVE_FILES_SUCCESS:
            return moveFiles(state, action);
        case FileManagerActionTypes.LOAD_FILES_SUCCESS:
            return loadFiles(state, action);
        case FileManagerActionTypes.SELECT_ALL:
            return selectAllFiles(state);
        case FileManagerActionTypes.SELECT_FILE:
            return selectFile(state, action);
        case FileManagerActionTypes.UNSELECT_ALL:
            return unSelectAllFiles(state);
        case FileManagerActionTypes.UNSELECT_FILE:
            return unSelectFile(state, action);
        case FileManagerActionTypes.UPLOAD_FILE_SUCCESS:
            return uploadFiles(state, action);
        case FileManagerActionTypes.DELETE_FILE_SELECTION:
        case FileManagerActionTypes.CROP_FILE:
        case FileManagerActionTypes.DELETE_FILE:
        case FileManagerActionTypes.LOAD_FILES:
        case FileManagerActionTypes.MOVE_FILES_ERROR:
            return state;
        default:
            return state;
    }
}
/** @type {?} */
const filemanagerStateSelector = createFeatureSelector('files');
/** @type {?} */
const getAll = (/**
 * @param {?} state
 * @return {?}
 */
(state) => {
    return state.files.map((/**
     * @param {?} id
     * @return {?}
     */
    (id) => state.entities[id]));
});
/** @type {?} */
const isChangeStateFiles = (/**
 * @param {?} newState
 * @param {?} prevState
 * @return {?}
 */
(newState, prevState) => {
    return prevState.files.length !== newState.files.length || prevState.files.filter((/**
     * @param {?} i
     * @return {?}
     */
    (i) => newState.files.indexOf(i) === -1)).length > 0;
});
/** @type {?} */
const isChangeStateSelectedFiles = (/**
 * @param {?} newState
 * @param {?} prevState
 * @return {?}
 */
(newState, prevState) => {
    return prevState.selectedFiles.length !== newState.selectedFiles.length || prevState.selectedFiles.filter((/**
     * @param {?} i
     * @return {?}
     */
    (i) => newState.selectedFiles.indexOf(i) === -1)).length > 0;
});

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CurrentDirectoryFilesService {
    /**
     * @param {?} store
     * @param {?} fileTypeFilter
     * @param {?} searchFilterService
     */
    constructor(store, fileTypeFilter, searchFilterService) {
        this.store = store;
        this.fileTypeFilter = fileTypeFilter;
        this.searchFilterService = searchFilterService;
        /** @type {?} */
        const store$ = this.store.select(filemanagerStateSelector);
        /** @type {?} */
        const observable$ = store$;
        this.entities$ = observable$
            .pipe(map((/**
         * @param {?} state
         * @return {?}
         */
        (state) => state.entities)), distinctUntilChanged());
        this.currentDirectoryFileIds$ = observable$
            .pipe(map((/**
         * @param {?} state
         * @return {?}
         */
        (state) => state.files)), distinctUntilChanged());
        this.selectedFiles$ = store$
            .pipe(map((/**
         * @param {?} state
         * @return {?}
         */
        (state) => state.selectedFiles)));
        this.files$ = this.getFilesStream();
        this.filteredFiles$ = this.getCurrentDirectoryFilesStream();
    }
    /**
     * Return stream of files
     * @private
     * @return {?}
     */
    getFilesStream() {
        return this.currentDirectoryFileIds$
            .pipe(withLatestFrom(this.entities$), map((/**
         * @param {?} ar
         * @return {?}
         */
        (ar) => {
            return {
                entities: ar[1],
                files: ar[0]
            };
        })), map((/**
         * @param {?} state
         * @return {?}
         */
        (state) => {
            return getAll(state)
                .map((/**
             * @param {?} file
             * @return {?}
             */
            (file) => {
                return new FileModel(file);
            }));
        })));
    }
    /**
     * Return stream of current directory filtered files
     * @private
     * @return {?}
     */
    getCurrentDirectoryFilesStream() {
        return combineLatest(this.files$, this.fileTypeFilter.filter$, this.searchFilterService.filter$)
            .pipe(map((/**
         * @param {?} data
         * @return {?}
         */
        (data) => {
            /** @type {?} */
            let files = data[0];
            /** @type {?} */
            const fileTypeFilter = data[1];
            /** @type {?} */
            const search = data[2].toLocaleLowerCase();
            if (search !== '') {
                files = files.filter((/**
                 * @param {?} file
                 * @return {?}
                 */
                (file) => {
                    return file.name.toLocaleLowerCase().indexOf(search) > -1;
                }));
            }
            if (fileTypeFilter && fileTypeFilter.mimes.length > 0) {
                files = files.filter((/**
                 * @param {?} file
                 * @return {?}
                 */
                (file) => {
                    return fileTypeFilter.mimes.indexOf(file.getMime()) > -1;
                }));
            }
            return files;
        })));
    }
}
CurrentDirectoryFilesService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
CurrentDirectoryFilesService.ctorParameters = () => [
    { type: Store },
    { type: FileTypeFilterService },
    { type: SearchFilterService }
];
if (false) {
    /**
     * List of all files
     * @type {?}
     */
    CurrentDirectoryFilesService.prototype.files$;
    /**
     * List of files for current selected directory
     * @type {?}
     */
    CurrentDirectoryFilesService.prototype.filteredFiles$;
    /**
     * List of all files as JSON data
     * @type {?}
     */
    CurrentDirectoryFilesService.prototype.entities$;
    /**
     * List of selected file ids
     * @type {?}
     */
    CurrentDirectoryFilesService.prototype.selectedFiles$;
    /**
     * List of all files in current directory
     * @type {?}
     */
    CurrentDirectoryFilesService.prototype.currentDirectoryFileIds$;
    /**
     * @type {?}
     * @private
     */
    CurrentDirectoryFilesService.prototype.store;
    /**
     * @type {?}
     * @private
     */
    CurrentDirectoryFilesService.prototype.fileTypeFilter;
    /**
     * @type {?}
     * @private
     */
    CurrentDirectoryFilesService.prototype.searchFilterService;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileManagerApiService extends AbstractFileManagerApiService {
    /**
     * @param {?} filemanagerNotification
     */
    constructor(filemanagerNotification) {
        super();
        this.filemanagerNotification = filemanagerNotification;
    }
    /**
     * @return {?}
     */
    get treeId() {
        return FILEMANAGER_TREE_NAME;
    }
    /**
     * @param {?=} nodeId
     * @return {?}
     */
    load(nodeId = '') {
        if (!this.nodes) {
            this.nodes = this.getAllDataFromLocalStorage();
        }
        /** @type {?} */
        const nodes = this.getChildren(nodeId);
        return of(nodes);
    }
    /**
     * @param {?} node
     * @param {?=} parentNodeId
     * @return {?}
     */
    add(node, parentNodeId = null) {
        node.parentId = parentNodeId;
        node.id = UUID.UUID();
        this.nodes.push(node);
        if (this.saveNodes()) {
            return of(node);
        }
        else {
            return empty();
        }
    }
    /**
     * @param {?} srcNode
     * @param {?} targetNode
     * @return {?}
     */
    move(srcNode, targetNode) {
        /** @type {?} */
        const srcId = srcNode.id;
        /** @type {?} */
        const targetId = targetNode ? targetNode.id : '';
        /** @type {?} */
        const index = this.findIndexByNodeId(srcId);
        this.nodes[index].parentId = targetId;
        if (this.saveNodes()) {
            return of(this.nodes[index]);
        }
        else {
            return empty();
        }
    }
    /**
     * @param {?} node
     * @return {?}
     */
    update(node) {
        /** @type {?} */
        const index = this.findIndexByNodeId(node.id);
        this.nodes[index] = node;
        if (this.saveNodes()) {
            return of(node);
        }
        else {
            return empty();
        }
    }
    /**
     * @param {?} nodeId
     * @return {?}
     */
    remove(nodeId) {
        /** @type {?} */
        const index = this.findIndexByNodeId(nodeId);
        /** @type {?} */
        const node = this.nodes[index];
        /** @type {?} */
        const hasChildren = this.getChildren(nodeId).length > 0;
        if (!hasChildren) {
            this.nodes.splice(index, 1);
            this.saveNodes();
            return of(node);
        }
        else {
            return throwError('Node is not empty');
        }
    }
    /**
     * @param {?} nodes
     * @return {?}
     */
    setAllNodes(nodes) {
        this.nodes = [...nodes];
        this.saveNodes();
    }
    /**
     * Crop file
     * @param {?} file
     * @param {?} bounds
     * @return {?}
     */
    cropFile(file, bounds) {
        return throwError('This functionality is not available with LocalStorage');
    }
    /**
     * Load files from directory
     * @param {?=} nodeId
     * @return {?}
     */
    loadFiles(nodeId = '') {
        this.currentNodeId = nodeId;
        if (!this.files) {
            this.files = this.getAllFileDataFromLocalStorage();
        }
        /** @type {?} */
        const files = this.getFilesFromFolder(nodeId);
        /** @type {?} */
        const newFiles = files.map((/**
         * @param {?} file
         * @return {?}
         */
        (file) => {
            return this.convertLocalData2IOuterFile(file);
        }));
        return of(newFiles);
    }
    /**
     * @param {?} file
     * @return {?}
     */
    removeFile(file) {
        /** @type {?} */
        const index = this.findIndexByFileId(file.id.toString());
        if (index === -1) {
            return of(false);
        }
        this.files.splice(index, 1);
        this.saveFiles();
        return of(true);
    }
    /**
     * @param {?} selectedFiles
     * @return {?}
     */
    removeSelectedFiles(selectedFiles) {
        /** @type {?} */
        const numberOfFiles = this.files.length;
        selectedFiles.forEach((/**
         * @param {?} fileId
         * @return {?}
         */
        (fileId) => {
            /** @type {?} */
            const index = this.findIndexByFileId(fileId);
            if (index > -1) {
                this.files.splice(index, 1);
            }
        }));
        this.saveFiles();
        return of((this.files.length + selectedFiles.length === numberOfFiles));
    }
    /**
     * @param {?} file
     * @return {?}
     */
    uploadFile(file) {
        /** @type {?} */
        const fileData = this.convertIOuterFile2LocalData(file);
        this.files.push(fileData);
        if (this.saveFiles()) {
            return of(this.convertLocalData2IOuterFile(fileData));
        }
        else {
            return Observable.throw('Upload error');
        }
    }
    /**
     * @param {?} files
     * @param {?=} node
     * @return {?}
     */
    moveFile(files, node = null) {
        /** @type {?} */
        const ids = files.map((/**
         * @param {?} file
         * @return {?}
         */
        file => file.id.toString()));
        /** @type {?} */
        const folderId = node ? node.id.toString() : '';
        /** @type {?} */
        const movedFiles = this.files.filter((/**
         * @param {?} file
         * @return {?}
         */
        file => ids.indexOf(file.id.toString()) > -1));
        /** @type {?} */
        const errorMsg = 'Can not move file to the same folder';
        /** @type {?} */
        const isMovedToSameFolder = false;
        movedFiles.forEach((/**
         * @param {?} file
         * @return {?}
         */
        (file) => {
            if (node) {
                if (node.id === file.folderId) {
                }
            }
            else {
                if (file.folderId === '' || file.folderId === null) {
                    return Observable.throw(errorMsg);
                }
            }
            file.folderId = folderId;
        }));
        if (isMovedToSameFolder) {
            return Observable.throw(errorMsg);
        }
        if (this.saveFiles()) {
            return of(movedFiles.map((/**
             * @param {?} file
             * @return {?}
             */
            file => this.convertLocalData2IOuterFile(file))));
        }
        else {
            return Observable.throw('Move files error');
        }
    }
    /**
     * @private
     * @param {?} nodeId
     * @return {?}
     */
    findIndexByNodeId(nodeId) {
        return this.nodes.findIndex((/**
         * @param {?} node
         * @return {?}
         */
        (node) => {
            return node.id === nodeId;
        }));
    }
    /**
     * @private
     * @param {?} fileId
     * @return {?}
     */
    findIndexByFileId(fileId) {
        return this.files.findIndex((/**
         * @param {?} file
         * @return {?}
         */
        (file) => file.id === fileId));
    }
    /**
     * @private
     * @param {?} nodeId
     * @return {?}
     */
    getChildren(nodeId) {
        return this.nodes.filter((/**
         * @param {?} node
         * @return {?}
         */
        (node) => node.parentId === nodeId));
    }
    /**
     * @private
     * @param {?} nodeId
     * @return {?}
     */
    getFilesFromFolder(nodeId) {
        return this.files.filter((/**
         * @param {?} file
         * @return {?}
         */
        (file) => file.folderId === nodeId));
    }
    /**
     * @protected
     * @return {?}
     */
    getAllDataFromLocalStorage() {
        try {
            /** @type {?} */
            const data = localStorage.getItem(this.treeName);
            if (data) {
                return JSON.parse(data);
            }
            return [];
        }
        catch (e) {
            return [];
        }
    }
    /**
     * @protected
     * @return {?}
     */
    getAllFileDataFromLocalStorage() {
        try {
            /** @type {?} */
            const data = localStorage.getItem(this.fileManagerName);
            if (data) {
                return JSON.parse(data);
            }
            return [];
        }
        catch (e) {
            return [];
        }
    }
    /**
     * @private
     * @return {?}
     */
    saveNodes() {
        try {
            localStorage.setItem(this.treeName, JSON.stringify(this.nodes));
            return true;
        }
        catch (e) {
            this.filemanagerNotification.send({
                type: 'error',
                title: 'State is not saved.',
                message: 'Reload previous state.'
            });
            this.files = null;
            this.nodes = null;
            this.load();
            return false;
        }
    }
    /**
     * @private
     * @return {?}
     */
    saveFiles() {
        try {
            localStorage.setItem(this.fileManagerName, JSON.stringify(this.files));
            return true;
        }
        catch (e) {
            this.filemanagerNotification.send({
                type: 'error',
                title: 'State is not saved.',
                message: 'Reload previous state.'
            });
            /** @type {?} */
            const nodeId = this.files[(this.files.length - 1)].folderId || null;
            this.files = null;
            this.load(nodeId);
            return false;
        }
    }
    /**
     * @private
     * @param {?} file
     * @return {?}
     */
    convertLocalData2IOuterFile(file) {
        return {
            id: file.id,
            folderId: file.folderId,
            name: file.name,
            thumbnailUrl: file.data,
            url: file.data,
            width: file.width,
            height: file.height,
            type: file.type,
            size: file.size
        };
    }
    /**
     * @private
     * @param {?} file
     * @return {?}
     */
    convertIOuterFile2LocalData(file) {
        return {
            id: file.id.toString(),
            folderId: file.folderId,
            name: file.name,
            type: file.type,
            data: file.data,
            size: file.size,
            width: file.width,
            height: file.height
        };
    }
}
FileManagerApiService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
FileManagerApiService.ctorParameters = () => [
    { type: FilemanagerNotifications }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    FileManagerApiService.prototype.filemanagerNotification;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileManagerBackendApiService extends AbstractFileManagerApiService {
    /**
     * @param {?} $http
     * @param {?} configuration
     */
    constructor($http, configuration) {
        super();
        this.$http = $http;
        this.configuration = configuration;
        this.nodes = [];
        this.files = [];
    }
    /**
     * @return {?}
     */
    get treeId() {
        return FILEMANAGER_TREE_NAME;
    }
    /**
     * Load folder chidls for given folder id
     * @param {?=} nodeId
     * @return {?}
     */
    load(nodeId = '') {
        /** @type {?} */
        const nodeIds = this.nodes.map((/**
         * @param {?} node
         * @return {?}
         */
        (node) => node.id));
        /** @type {?} */
        const params = new HttpParams().set('nodeId', nodeId || '');
        return this.$http.get(this.configuration.folderUrls.foldersUrl, { params })
            .pipe(map((/**
         * @param {?} nodes
         * @return {?}
         */
        (nodes) => {
            nodes.forEach((/**
             * @param {?} node
             * @return {?}
             */
            (node) => {
                if (nodeIds.indexOf(node.id) === -1) {
                    this.nodes.push(node);
                }
                else {
                    /** @type {?} */
                    const index = this.nodes.findIndex((/**
                     * @param {?} item
                     * @return {?}
                     */
                    (item) => node.id === item.id));
                    this.nodes[index] = node;
                }
            }));
            return nodes;
        })));
    }
    /**
     * Create new folder
     * @param {?} node
     * @param {?=} parentNodeId
     * @return {?}
     */
    add(node, parentNodeId = null) {
        /** @type {?} */
        const data = {
            node: node,
            parentNodeId: parentNodeId
        };
        return this.$http.post(this.configuration.folderUrls.foldersUrl, data)
            .pipe(map((/**
         * @param {?} newNode
         * @return {?}
         */
        (newNode) => {
            this.nodes.push(newNode);
            return newNode;
        })));
    }
    /**
     * Move folder from source parent to target parent
     * @param {?} srcNode
     * @param {?} targetNode
     * @return {?}
     */
    move(srcNode, targetNode) {
        /** @type {?} */
        const srcId = srcNode.id;
        /** @type {?} */
        const targetId = targetNode ? targetNode.id : null;
        return this.$http.put(this.configuration.folderUrls.folderMoveUrl, { source: srcId, target: targetId })
            .pipe(map((/**
         * @param {?} movedNode
         * @return {?}
         */
        (movedNode) => {
            /** @type {?} */
            const index = this.findIndexByNodeId(srcId);
            this.nodes[index].parentId = targetId;
            return movedNode;
        })));
    }
    /**
     * Update folder name
     * @param {?} node
     * @return {?}
     */
    update(node) {
        return this.$http.put(this.configuration.folderUrls.foldersUrl, node)
            .pipe(map((/**
         * @param {?} newNode
         * @return {?}
         */
        (newNode) => {
            /** @type {?} */
            const index = this.findIndexByNodeId(node.id);
            this.nodes[index] = newNode;
            return newNode;
        })));
    }
    /**
     * Remove node by given id
     * @param {?} nodeId
     * @return {?}
     */
    remove(nodeId) {
        /** @type {?} */
        const index = this.findIndexByNodeId(nodeId);
        /** @type {?} */
        const hasChildren = this.getChildren(nodeId).length > 0;
        if (!hasChildren) {
            /** @type {?} */
            const params = new HttpParams().set('nodeId', nodeId);
            return this.$http.delete(this.configuration.folderUrls.foldersUrl, { params })
                .pipe(map((/**
             * @param {?} removedNode
             * @return {?}
             */
            (removedNode) => {
                this.nodes.splice(index, 1);
                return removedNode;
            })));
        }
        else {
            return Observable.throw('Node is not empty');
        }
    }
    /**
     * @param {?} nodes
     * @return {?}
     */
    setAllNodes(nodes) {
        this.nodes = [...nodes];
    }
    /**
     * Crop file
     * @param {?} file
     * @param {?} bounds
     * @return {?}
     */
    cropFile(file, bounds) {
        return this.$http.put(this.configuration.fileUrl, { id: file.id, bounds: bounds });
    }
    /**
     * Load files from directory
     * @param {?=} nodeId
     * @return {?}
     */
    loadFiles(nodeId = '') {
        this.currentNodeId = nodeId;
        /** @type {?} */
        const params = new HttpParams().set('dirId', nodeId);
        return this.$http.get(this.configuration.fileUrl, { params })
            .pipe(map((/**
         * @param {?} files
         * @return {?}
         */
        (files) => {
            this.files = files.map((/**
             * @param {?} file
             * @return {?}
             */
            (file) => (/** @type {?} */ (file))));
            return files;
        })));
    }
    /**
     * Remove file from folder
     * @param {?} file
     * @return {?}
     */
    removeFile(file) {
        /** @type {?} */
        const index = this.findIndexByFileId(file.id.toString());
        if (index === -1) {
            return of(false);
        }
        /** @type {?} */
        const params = new HttpParams().set('id', file.id.toString());
        return this.$http.delete(this.configuration.fileUrl, { params })
            .pipe(map((/**
         * @return {?}
         */
        () => {
            this.files.splice(index, 1);
            return true;
        })));
    }
    /**
     * @param {?} selectedFiles
     * @return {?}
     */
    removeSelectedFiles(selectedFiles) {
        /** @type {?} */
        const params = new HttpParams().set('id', selectedFiles.join('|'));
        return this.$http.delete(this.configuration.fileUrl, { params })
            .pipe(map((/**
         * @return {?}
         */
        () => {
            selectedFiles.forEach((/**
             * @param {?} fileId
             * @return {?}
             */
            (fileId) => {
                /** @type {?} */
                const index = this.findIndexByFileId(fileId);
                if (index > -1) {
                    this.files.splice(index, 1);
                }
            }));
            return true;
        })));
    }
    /**
     * This method is success method, real upload is done in ExtendedFileUploader
     * @param {?} file
     * @return {?}
     */
    uploadFile(file) {
        /** @type {?} */
        const fileData = (/** @type {?} */ (file));
        this.files.push(fileData);
        return of(file);
    }
    /**
     * @param {?} files
     * @param {?} node
     * @return {?}
     */
    moveFile(files, node) {
        /** @type {?} */
        const ids = files.map((/**
         * @param {?} file
         * @return {?}
         */
        file => file.id.toString()));
        return this.$http.put(this.configuration.fileUrl, { files: ids, folderId: node ? node.id : '' });
    }
    /**
     * @private
     * @param {?} nodeId
     * @return {?}
     */
    findIndexByNodeId(nodeId) {
        return this.nodes.findIndex((/**
         * @param {?} node
         * @return {?}
         */
        (node) => {
            return node.id === nodeId;
        }));
    }
    /**
     * @private
     * @param {?} fileId
     * @return {?}
     */
    findIndexByFileId(fileId) {
        return this.files.findIndex((/**
         * @param {?} file
         * @return {?}
         */
        (file) => file.id === fileId));
    }
    /**
     * @private
     * @param {?} nodeId
     * @return {?}
     */
    getChildren(nodeId) {
        return this.nodes.filter((/**
         * @param {?} node
         * @return {?}
         */
        (node) => node.parentId === nodeId));
    }
    /**
     * @private
     * @param {?} file
     * @return {?}
     */
    convertLocalData2IOuterFile(file) {
        return {
            id: file.id,
            folderId: file.folderId,
            name: file.name,
            thumbnailUrl: file.data,
            url: file.data,
            width: file.width,
            height: file.height,
            type: file.type,
            size: file.size
        };
    }
    /**
     * @private
     * @param {?} file
     * @return {?}
     */
    convertIOuterFile2LocalData(file) {
        return {
            id: file.id.toString(),
            folderId: file.folderId,
            name: file.name,
            type: file.type,
            data: file.data,
            size: file.size,
            width: file.width,
            height: file.height
        };
    }
}
FileManagerBackendApiService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
FileManagerBackendApiService.ctorParameters = () => [
    { type: HttpClient },
    { type: FileManagerConfiguration }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    FileManagerBackendApiService.prototype.$http;
    /**
     * @type {?}
     * @private
     */
    FileManagerBackendApiService.prototype.configuration;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileManagerEffectsService {
    /**
     * @param {?} actions$
     * @param {?} filemanagerNotification
     * @param {?} fileManagerApiService
     */
    constructor(actions$, filemanagerNotification, fileManagerApiService) {
        this.actions$ = actions$;
        this.filemanagerNotification = filemanagerNotification;
        this.fileManagerApiService = fileManagerApiService;
        this.cropFileSuccess$ = this.actions$
            .pipe(ofType(FileManagerActionTypes.CROP_FILE_SUCCESS));
        this.deleteFileSuccess$ = this.actions$
            .pipe(ofType(FileManagerActionTypes.DELETE_FILE_SUCCESS));
        this.loadFiles$ = this.actions$
            .pipe(ofType(FileManagerActionTypes.LOAD_FILES), switchMap((/**
         * @param {?} action
         * @return {?}
         */
        (action) => this.loadFiles(action.payload.folderId)
            .pipe(map((/**
         * @param {?} files
         * @return {?}
         */
        (files) => {
            return new LoadFilesSuccessAction({ files });
        })), catchError((/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            return of(this.onLoadFilesError(action.payload.folderId));
        }))))));
        this.cropFile$ = this.actions$
            .pipe(ofType(FileManagerActionTypes.CROP_FILE), switchMap((/**
         * @param {?} action
         * @return {?}
         */
        (action) => this.cropFile(action.payload.file, action.payload.bounds)
            .pipe(map((/**
         * @param {?} result
         * @return {?}
         */
        (result) => {
            this.filemanagerNotification.send({
                type: 'success',
                title: 'Crop Image.',
                message: 'Image has been cropped.'
            });
            return new CropFileSuccessAction({ file: action.payload.file });
        })), catchError((/**
         * @return {?}
         */
        () => of(new CropFileErrorAction({ file: action.payload.file }))))))));
        this.deleteFile$ = this.actions$
            .pipe(ofType(FileManagerActionTypes.DELETE_FILE), switchMap((/**
         * @param {?} action
         * @return {?}
         */
        (action) => this.deleteFile(action.payload.file)
            .pipe(map((/**
         * @param {?} result
         * @return {?}
         */
        (result) => {
            return new DeleteFileSuccessAction({ file: action.payload.file });
        })), catchError((/**
         * @return {?}
         */
        () => of(this.onDeleteFileError(action.payload.file))))))));
        this.deleteFilesSelection$ = this.actions$
            .pipe(ofType(FileManagerActionTypes.DELETE_FILE_SELECTION), switchMap((/**
         * @param {?} action
         * @return {?}
         */
        (action) => this.deleteFilesSelection(action.payload.files)
            .pipe(map((/**
         * @param {?} result
         * @return {?}
         */
        (result) => {
            return new DeleteSelectedFilesSuccessAction({ files: action.payload.files });
        })), catchError((/**
         * @return {?}
         */
        () => of(this.onDeleteFilesSelectionError())))))));
        this.uploadFile$ = this.actions$
            .pipe(ofType(FileManagerActionTypes.UPLOAD_FILE), switchMap((/**
         * @param {?} action
         * @return {?}
         */
        (action) => this.uploadFile(action.payload.files[0])
            .pipe(map((/**
         * @param {?} result
         * @return {?}
         */
        (result) => {
            return new UploadFilesSuccessAction({ files: [result] });
        })), catchError((/**
         * @return {?}
         */
        () => {
            return empty();
        }))))));
        this.moveFile$ = this.actions$
            .pipe(ofType(TreeActionTypes.TREE_MOVE_NODE), filter((/**
         * @param {?} action
         * @return {?}
         */
        (action) => {
            return action.payload.sourceOfDroppedData === 'FILE';
        })), switchMap((/**
         * @param {?} action
         * @return {?}
         */
        (action) => this.moveFiles([(/** @type {?} */ (action.payload.oldNode))], action.payload.node)
            .pipe(map((/**
         * @param {?} result
         * @return {?}
         */
        (result) => {
            /** @type {?} */
            const folderId = ((/** @type {?} */ (action.payload.oldNode))).folderId;
            return new MoveFilesSuccessAction({ files: result, folderId });
        })), catchError((/**
         * @return {?}
         */
        () => {
            return of(new MoveFilesErrorAction({ files: [(/** @type {?} */ (action.payload.oldNode))] }));
        }))))));
        this.filesMoveSuccess$ = this.actions$
            .pipe(ofType(FileManagerActionTypes.MOVE_FILES_SUCCESS), map((/**
         * @param {?} action
         * @return {?}
         */
        (action) => {
            this.onMoveFilesSuccess();
            return new LoadFilesAction({ folderId: action.payload.folderId });
        })));
        this.deleteFileSuccessEffect$ = this.deleteFileSuccess$
            .pipe(map((/**
         * @param {?} action
         * @return {?}
         */
        (action) => {
            this.filemanagerNotification.send({
                type: 'success',
                title: 'File delete',
                message: `${action.payload.file.name} has been deleted`
            });
        })));
        this.uploadError$ = this.actions$
            .pipe(ofType(FileManagerActionTypes.UPLOAD_FILE_ERROR), map((/**
         * @param {?} action
         * @return {?}
         */
        (action) => {
            this.filemanagerNotification.send({
                type: 'alert',
                title: 'File upload',
                message: `${action.payload.files[0].name} exists on the server in this directory`
            });
        })));
        this.actions$
            .pipe(ofType(FileManagerActionTypes.CROP_FILE_ERROR))
            .subscribe((/**
         * @param {?} action
         * @return {?}
         */
        (action) => {
            this.onCropFileError(action.payload.file);
        }));
        this.actions$
            .pipe(ofType(FileManagerActionTypes.MOVE_FILES_ERROR))
            .subscribe((/**
         * @param {?} action
         * @return {?}
         */
        (action) => {
            this.onMoveFilesError();
        }));
    }
    /**
     * @protected
     * @param {?} file
     * @param {?} bounds
     * @return {?}
     */
    cropFile(file, bounds) {
        return this.fileManagerApiService.cropFile(file.toJSON(), bounds);
    }
    /**
     * @protected
     * @param {?} file
     * @return {?}
     */
    deleteFile(file) {
        return this.fileManagerApiService.removeFile(file.toJSON());
    }
    /**
     * @protected
     * @param {?} files
     * @return {?}
     */
    deleteFilesSelection(files) {
        return this.fileManagerApiService.removeSelectedFiles(files);
    }
    /**
     * @protected
     * @param {?} folderId
     * @return {?}
     */
    loadFiles(folderId) {
        return this.fileManagerApiService.loadFiles(folderId);
    }
    /**
     * @protected
     * @param {?} file
     * @return {?}
     */
    uploadFile(file) {
        return this.fileManagerApiService.uploadFile(file);
    }
    /**
     * @protected
     * @param {?} files
     * @param {?=} folder
     * @return {?}
     */
    moveFiles(files, folder = null) {
        return this.fileManagerApiService.moveFile(files, folder);
    }
    /**
     * @protected
     * @param {?} file
     * @return {?}
     */
    onCropFileError(file) {
        this.filemanagerNotification.send({
            type: 'alert',
            title: 'Crop Image',
            message: '[FILEMANAGER] Can not crop file'
        });
    }
    /**
     * @protected
     * @param {?} file
     * @return {?}
     */
    onDeleteFileError(file) {
        this.filemanagerNotification.send({
            type: 'error',
            title: 'Delete file',
            message: '[FILEMANAGER] Can not delete file' + file.name
        });
    }
    /**
     * @protected
     * @return {?}
     */
    onDeleteFilesSelectionError() {
        this.filemanagerNotification.send({
            type: 'error',
            title: 'Delete selected files',
            message: '[FILEMANAGER] Not all files were deleted'
        });
    }
    /**
     * @protected
     * @param {?} folderId
     * @return {?}
     */
    onLoadFilesError(folderId) {
        this.filemanagerNotification.send({
            type: 'error',
            title: 'Load files',
            message: '[FILEMANAGER] Can not load files for folder ' + folderId
        });
    }
    /**
     * @protected
     * @return {?}
     */
    onMoveFilesSuccess() {
        this.filemanagerNotification.send({
            type: 'success',
            title: 'Move files',
            message: 'File was successfully moved to folder'
        });
    }
    /**
     * @protected
     * @return {?}
     */
    onMoveFilesError() {
        this.filemanagerNotification.send({
            type: 'error',
            title: 'Move files',
            message: 'File was not successfully moved to new folder'
        });
    }
}
FileManagerEffectsService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
FileManagerEffectsService.ctorParameters = () => [
    { type: Actions },
    { type: FilemanagerNotifications },
    { type: FileManagerApiService }
];
__decorate([
    Effect(),
    __metadata("design:type", Object)
], FileManagerEffectsService.prototype, "loadFiles$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], FileManagerEffectsService.prototype, "cropFile$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], FileManagerEffectsService.prototype, "deleteFile$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], FileManagerEffectsService.prototype, "deleteFilesSelection$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], FileManagerEffectsService.prototype, "uploadFile$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], FileManagerEffectsService.prototype, "moveFile$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], FileManagerEffectsService.prototype, "filesMoveSuccess$", void 0);
__decorate([
    Effect({ dispatch: false }),
    __metadata("design:type", Object)
], FileManagerEffectsService.prototype, "deleteFileSuccessEffect$", void 0);
if (false) {
    /** @type {?} */
    FileManagerEffectsService.prototype.cropFileSuccess$;
    /** @type {?} */
    FileManagerEffectsService.prototype.deleteFileSuccess$;
    /** @type {?} */
    FileManagerEffectsService.prototype.loadFiles$;
    /** @type {?} */
    FileManagerEffectsService.prototype.cropFile$;
    /** @type {?} */
    FileManagerEffectsService.prototype.deleteFile$;
    /** @type {?} */
    FileManagerEffectsService.prototype.deleteFilesSelection$;
    /** @type {?} */
    FileManagerEffectsService.prototype.uploadFile$;
    /** @type {?} */
    FileManagerEffectsService.prototype.moveFile$;
    /** @type {?} */
    FileManagerEffectsService.prototype.filesMoveSuccess$;
    /** @type {?} */
    FileManagerEffectsService.prototype.deleteFileSuccessEffect$;
    /** @type {?} */
    FileManagerEffectsService.prototype.uploadError$;
    /**
     * @type {?}
     * @private
     */
    FileManagerEffectsService.prototype.actions$;
    /**
     * @type {?}
     * @private
     */
    FileManagerEffectsService.prototype.filemanagerNotification;
    /**
     * @type {?}
     * @private
     */
    FileManagerEffectsService.prototype.fileManagerApiService;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IFileManagerApi() { }
if (false) {
    /**
     * @param {?} node
     * @param {?} parentNodeId
     * @return {?}
     */
    IFileManagerApi.prototype.add = function (node, parentNodeId) { };
    /**
     * @param {?} nodeId
     * @return {?}
     */
    IFileManagerApi.prototype.load = function (nodeId) { };
    /**
     * @param {?} srcNode
     * @param {?} targetNode
     * @return {?}
     */
    IFileManagerApi.prototype.move = function (srcNode, targetNode) { };
    /**
     * @param {?} node
     * @return {?}
     */
    IFileManagerApi.prototype.update = function (node) { };
    /**
     * @param {?} nodeId
     * @return {?}
     */
    IFileManagerApi.prototype.remove = function (nodeId) { };
    /**
     * @param {?} file
     * @param {?} bounds
     * @return {?}
     */
    IFileManagerApi.prototype.cropFile = function (file, bounds) { };
    /**
     * @param {?} nodeId
     * @return {?}
     */
    IFileManagerApi.prototype.loadFiles = function (nodeId) { };
    /**
     * @param {?} file
     * @return {?}
     */
    IFileManagerApi.prototype.removeFile = function (file) { };
    /**
     * @param {?} selectedFiles
     * @return {?}
     */
    IFileManagerApi.prototype.removeSelectedFiles = function (selectedFiles) { };
    /**
     * @param {?} file
     * @return {?}
     */
    IFileManagerApi.prototype.uploadFile = function (file) { };
    /**
     * @param {?} files
     * @param {?} node
     * @return {?}
     */
    IFileManagerApi.prototype.moveFile = function (files, node) { };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileTypeFilterComponent {
    /**
     * @param {?} fileTypeFilter
     */
    constructor(fileTypeFilter) {
        this.fileTypeFilter = fileTypeFilter;
        this.typeFilterList = [];
        this.selectedType = null;
        this.fileTypeFilter.filter$
            .subscribe((/**
         * @param {?} type
         * @return {?}
         */
        (type) => {
            this.selectedType = type;
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** init file type filter **/
        this.typeFilterList
            .filter((/**
         * @param {?} type
         * @return {?}
         */
        (type) => {
            return type.defaultSelected;
        }))
            .forEach((/**
         * @param {?} type
         * @return {?}
         */
        (type) => {
            this.fileTypeFilter.setValue(type);
        }));
    }
    /**
     * Set current filter and fire event
     * @param {?} type
     * @return {?}
     */
    setFilterType(type) {
        this.fileTypeFilter.setValue(type);
    }
}
FileTypeFilterComponent.decorators = [
    { type: Component, args: [{
                selector: 'ri-file-type-filter',
                template: "<div class=\"btn-group\">\n  <button *ngFor=\"let type of typeFilterList\" class=\"btn btn-secondary\" [ngClass]=\"{'active': type === selectedType}\"\n          (click)=\"setFilterType(type)\">\n    <i class=\"{{type.iconCls}}\"></i>\n  </button>\n</div>\n"
            }] }
];
/** @nocollapse */
FileTypeFilterComponent.ctorParameters = () => [
    { type: FileTypeFilterService }
];
FileTypeFilterComponent.propDecorators = {
    typeFilterList: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    FileTypeFilterComponent.prototype.typeFilterList;
    /** @type {?} */
    FileTypeFilterComponent.prototype.selectedType;
    /**
     * @type {?}
     * @private
     */
    FileTypeFilterComponent.prototype.fileTypeFilter;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IAddFolder() { }
if (false) {
    /** @type {?} */
    IAddFolder.prototype.name;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IFileTypeFilter() { }
if (false) {
    /** @type {?} */
    IFileTypeFilter.prototype.name;
    /** @type {?} */
    IFileTypeFilter.prototype.mimes;
    /** @type {?} */
    IFileTypeFilter.prototype.iconCls;
    /** @type {?|undefined} */
    IFileTypeFilter.prototype.text;
    /** @type {?|undefined} */
    IFileTypeFilter.prototype.defaultSelected;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IToolbarEvent() { }
if (false) {
    /** @type {?} */
    IToolbarEvent.prototype.name;
    /** @type {?|undefined} */
    IToolbarEvent.prototype.value;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class IUploadItemEvent {
}
if (false) {
    /** @type {?} */
    IUploadItemEvent.prototype.name;
    /** @type {?} */
    IUploadItemEvent.prototype.response;
    /** @type {?} */
    IUploadItemEvent.prototype.status;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const Button = {
    ADD_FOLDER: 'ADD_FOLDER',
    CHOOSE_SELECTION: 'CHOOSE_SELECTION',
    DELETE_SELECTION: 'DELETE_SELECTION',
    INVERSE_SELECTION: 'INVERSE_SELECTION',
    REFRESH_FILES_LIST: 'REFRESH_FILES_LIST',
    SELECT_ALL: 'SELECT_ALL',
    UNSELECT_ALL: 'UNSELECT_ALL',
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ToolbarEventModel {
    /**
     * @param {?} name
     * @param {?=} value
     */
    constructor(name, value = null) {
        this.name = name;
        this.value = value;
    }
}
if (false) {
    /** @type {?} */
    ToolbarEventModel.prototype.name;
    /** @type {?} */
    ToolbarEventModel.prototype.value;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SearchFileComponent {
    /**
     * @param {?} searchFilterService
     * @param {?} filemanagerTranslations
     */
    constructor(searchFilterService, filemanagerTranslations) {
        this.searchFilterService = searchFilterService;
        this.filemanagerTranslations = filemanagerTranslations;
        this.searchField = new FormControl();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.searchField.valueChanges
            .pipe(debounceTime(250))
            .subscribe((/**
         * @param {?} value
         * @return {?}
         */
        (value) => this.searchFilterService.setValue(value)));
    }
}
SearchFileComponent.decorators = [
    { type: Component, args: [{
                selector: 'ri-search-file',
                template: "<div class=\"input-group\">\n  <input [formControl]=\"searchField\" type=\"text\" class=\"form-control\"\n         placeholder=\"{{filemanagerTranslations.RI_FM_LBL_SEARCH_FOR}}\">\n  <span class=\"input-group-append\">\n      <button (click)=\"searchField.reset('')\" class=\"btn btn-secondary\" type=\"button\">\n          <i class=\"fa fa-times\"></i>\n      </button>\n  </span>\n</div>\n"
            }] }
];
/** @nocollapse */
SearchFileComponent.ctorParameters = () => [
    { type: SearchFilterService },
    { type: undefined, decorators: [{ type: Inject, args: [FILEMANAGER_TRANSLATION_TOKEN,] }] }
];
if (false) {
    /** @type {?} */
    SearchFileComponent.prototype.searchField;
    /**
     * @type {?}
     * @private
     */
    SearchFileComponent.prototype.searchFilterService;
    /** @type {?} */
    SearchFileComponent.prototype.filemanagerTranslations;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class AbstractButtonClass {
    /**
     * @param {?} data
     */
    constructor(data) {
        this.symbol = data.symbol;
        this.name = data.name;
        this.label = data.label;
        this.icon = data.icon;
        this.iconCssClass = data.iconCssClass;
        this.disabled = data.disabled;
    }
}
if (false) {
    /** @type {?} */
    AbstractButtonClass.prototype.symbol;
    /** @type {?} */
    AbstractButtonClass.prototype.name;
    /** @type {?} */
    AbstractButtonClass.prototype.label;
    /** @type {?} */
    AbstractButtonClass.prototype.icon;
    /** @type {?} */
    AbstractButtonClass.prototype.iconCssClass;
    /** @type {?} */
    AbstractButtonClass.prototype.disabled;
    /**
     * @abstract
     * @return {?}
     */
    AbstractButtonClass.prototype.isDivider = function () { };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonClass extends AbstractButtonClass {
    /**
     * @return {?}
     */
    isDivider() {
        return false;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonDividerClass extends AbstractButtonClass {
    constructor() {
        super({
            symbol: '',
            name: '',
            label: false,
            icon: false,
            iconCssClass: ''
        });
    }
    /**
     * @return {?}
     */
    isDivider() {
        return true;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SelectionComponent {
    /**
     * @param {?} configuration
     * @param {?} currentDirectoryFilesService
     * @param {?} filemanagerTranslations
     */
    constructor(configuration, currentDirectoryFilesService, filemanagerTranslations) {
        this.configuration = configuration;
        this.currentDirectoryFilesService = currentDirectoryFilesService;
        this.filemanagerTranslations = filemanagerTranslations;
        this.onMenuButtonClick = new EventEmitter();
        this.selectAllButton = new ButtonClass({
            symbol: Button.SELECT_ALL,
            name: this.filemanagerTranslations.RI_FM_LBL_SELECT_ALL,
            label: true,
            icon: true,
            iconCssClass: 'fa fa-check-square-o'
        });
        this.unselectAllButton = new ButtonClass({
            symbol: Button.UNSELECT_ALL,
            name: this.filemanagerTranslations.RI_FM_LBL_UNSELECT_ALL,
            label: true,
            icon: true,
            iconCssClass: 'fa fa-square-o'
        });
        this.inverseSelectionButton = new ButtonClass({
            symbol: Button.INVERSE_SELECTION,
            name: this.filemanagerTranslations.RI_FM_LBL_INVERSE_SELECTION,
            label: true,
            icon: true,
            iconCssClass: 'fa fa-check-square'
        });
        this.deleteSelectionButton = new ButtonClass({
            symbol: Button.DELETE_SELECTION,
            name: this.filemanagerTranslations.RI_FM_LBL_DELETE_SELECTION,
            label: true,
            icon: true,
            iconCssClass: 'fa fa-trash'
        });
        this.chooseSelectionButton = new ButtonClass({
            symbol: Button.CHOOSE_SELECTION,
            name: this.filemanagerTranslations.RI_FM_LBL_CHOOSE_SELECTION,
            label: true,
            icon: true,
            iconCssClass: 'fa fa-image'
        });
        this.selectButtonsList = this.createBasicButtons();
        this.initListenOnLoadFiles();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.onLoadFilesSubscriber.unsubscribe();
    }
    /**
     * Initialize listener on load files
     * @return {?}
     */
    initListenOnLoadFiles() {
        this.onLoadFilesSubscriber = combineLatest(this.currentDirectoryFilesService.currentDirectoryFileIds$, this.currentDirectoryFilesService.selectedFiles$)
            .pipe(distinctUntilChanged())
            .subscribe((/**
         * @param {?} data
         * @return {?}
         */
        (data) => {
            /** @type {?} */
            const numberOfFiles = data[0].length;
            /** @type {?} */
            const numberOfSelectedFiles = data[1].length;
            this.disableAllButtons();
            if (numberOfFiles > 0) {
                if (numberOfSelectedFiles > 0) {
                    this.enableAllButtons();
                }
                else {
                    this.enableSelectAllButton();
                }
            }
        }));
    }
    /**
     * @param {?} button
     * @return {?}
     */
    onSelectDropdownClick(button) {
        /** @type {?} */
        const event = new ToolbarEventModel(button.symbol);
        this.onMenuButtonClick.emit(event);
    }
    /**
     * Disable all dropdown buttons and main button
     * @private
     * @return {?}
     */
    disableAllButtons() {
        this.selectAllButton.disabled = true;
        this.selectButtonsList
            .filter((/**
         * @param {?} button
         * @return {?}
         */
        (button) => {
            return !button.isDivider();
        }))
            .forEach((/**
         * @param {?} button
         * @return {?}
         */
        (button) => {
            button.disabled = true;
        }));
    }
    /**
     * Enable all dropdown buttons and main button
     * @private
     * @return {?}
     */
    enableAllButtons() {
        this.selectAllButton.disabled = false;
        this.selectButtonsList
            .forEach((/**
         * @param {?} button
         * @return {?}
         */
        (button) => {
            button.disabled = false;
        }));
    }
    /**
     * Create list of buttons
     * @private
     * @return {?}
     */
    createBasicButtons() {
        /** @type {?} */
        const buttons = [
            this.selectAllButton,
            this.unselectAllButton,
            this.inverseSelectionButton,
            new ButtonDividerClass(),
            this.deleteSelectionButton,
        ];
        if (this.configuration.allowChooseMultipleFiles) {
            buttons.push(new ButtonDividerClass());
            buttons.push(this.chooseSelectionButton);
        }
        return buttons;
    }
    /**
     * Enable only select button
     * @private
     * @return {?}
     */
    enableSelectAllButton() {
        this.selectAllButton.disabled = false;
        this.inverseSelectionButton.disabled = false;
    }
}
SelectionComponent.decorators = [
    { type: Component, args: [{
                selector: 'ri-selection-dropdown',
                template: "<ri-dropdown *ngIf=\"configuration.isMultiSelection\" [mainButton]=\"selectAllButton\" [buttons]=\"selectButtonsList\"\n             (onClick)=\"onSelectDropdownClick($event)\"></ri-dropdown>\n"
            }] }
];
/** @nocollapse */
SelectionComponent.ctorParameters = () => [
    { type: FileManagerConfiguration },
    { type: CurrentDirectoryFilesService },
    { type: undefined, decorators: [{ type: Inject, args: [FILEMANAGER_TRANSLATION_TOKEN,] }] }
];
SelectionComponent.propDecorators = {
    onMenuButtonClick: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    SelectionComponent.prototype.onMenuButtonClick;
    /** @type {?} */
    SelectionComponent.prototype.selectButtonsList;
    /** @type {?} */
    SelectionComponent.prototype.selectAllButton;
    /**
     * @type {?}
     * @private
     */
    SelectionComponent.prototype.unselectAllButton;
    /**
     * @type {?}
     * @private
     */
    SelectionComponent.prototype.inverseSelectionButton;
    /**
     * @type {?}
     * @private
     */
    SelectionComponent.prototype.deleteSelectionButton;
    /**
     * @type {?}
     * @private
     */
    SelectionComponent.prototype.chooseSelectionButton;
    /**
     * @type {?}
     * @private
     */
    SelectionComponent.prototype.onLoadFilesSubscriber;
    /** @type {?} */
    SelectionComponent.prototype.configuration;
    /**
     * @type {?}
     * @private
     */
    SelectionComponent.prototype.currentDirectoryFilesService;
    /** @type {?} */
    SelectionComponent.prototype.filemanagerTranslations;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ToolbarComponent {
    /**
     * @param {?} configuration
     * @param {?} fileManagerUploader
     * @param {?} store
     */
    constructor(configuration, fileManagerUploader, store) {
        this.configuration = configuration;
        this.fileManagerUploader = fileManagerUploader;
        this.store = store;
        this.onAddFolderClick = new EventEmitter();
        this.onUpload = new EventEmitter();
        this.onMenuButtonClick = new EventEmitter();
        this.fileManagerUploader.clear();
        this.fileManagerUploader.uploader.onCompleteAll = (/**
         * @return {?}
         */
        () => {
            this.onUpload.emit(this.currentFolderId || '');
        });
        this.fileManagerUploader.uploader.onCompleteItem = (/**
         * @param {?} item
         * @param {?} response
         * @param {?} status
         * @param {?} headers
         * @return {?}
         */
        (item, response, status, headers) => {
            if (status === 200) {
                this.store.dispatch(new UploadFilesAction({ files: [JSON.parse(response)] }));
            }
            else {
                this.store.dispatch(new UploadFilesErrorAction({ files: JSON.parse(response) }));
            }
        });
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        this.fileManagerUploader.setDirectoryId(this.currentFolderId || '');
    }
    /**
     * @return {?}
     */
    addFolder() {
        /** @type {?} */
        const event = new ToolbarEventModel(Button.ADD_FOLDER, '');
        this.onAddFolderClick.emit(event);
    }
    /**
     * @return {?}
     */
    onRefreshFilesList() {
        /** @type {?} */
        const event = new ToolbarEventModel(Button.REFRESH_FILES_LIST);
        this.onMenuButtonClick.emit(event);
    }
}
ToolbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'ri-toolbar',
                template: "<div class=\"toolbar row\">\n  <div class=\"col-md-6\">\n    <div class=\"btn-group\">\n      <button class=\"btn btn-secondary\" (click)=\"addFolder()\">\n        <i class=\"fa fa-plus\"></i>\n        <i class=\"fa fa-folder-o\"></i>\n      </button>\n      <span class=\"hidden-input-file\">\n        <input #fileInput type=\"file\" ng2FileSelect [uploader]=\"fileManagerUploader.uploader\" multiple/>\n      </span>\n      <button class=\"btn btn-secondary\" (click)=\"fileInput.click()\">\n        <i class=\"fa fa-plus\"></i>\n        <i class=\"fa fa-file-o\"></i>\n      </button>\n    </div>\n    <ri-selection-dropdown (onMenuButtonClick)=\"onMenuButtonClick.next($event)\"></ri-selection-dropdown>\n    <div class=\"btn-group\">\n      <button class=\"btn btn-secondary\" (click)=\"onRefreshFilesList()\">\n        <i class=\"fa fa-refresh\"></i>\n      </button>\n    </div>\n  </div>\n  <div class=\"col-md-3\">\n    <ri-file-type-filter [typeFilterList]=\"configuration.fileTypesFilter\"></ri-file-type-filter>\n  </div>\n  <div class=\"col-md-3\">\n    <ri-search-file></ri-search-file>\n  </div>\n</div>\n",
                styles: [".toolbar{margin-bottom:10px}.btn{height:34px}.btn-file{position:relative;overflow:hidden}.hidden-input-file{visibility:hidden;position:absolute;overflow:hidden;width:0;height:0;border:none;margin:0;padding:0}.btn-group,ri-selection-dropdown{padding:0 2px 0 0}"]
            }] }
];
/** @nocollapse */
ToolbarComponent.ctorParameters = () => [
    { type: FileManagerConfiguration },
    { type: FileManagerUploader },
    { type: Store }
];
ToolbarComponent.propDecorators = {
    currentFolderId: [{ type: Input }],
    onAddFolderClick: [{ type: Output }],
    onUpload: [{ type: Output }],
    onMenuButtonClick: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    ToolbarComponent.prototype.currentFolderId;
    /** @type {?} */
    ToolbarComponent.prototype.onAddFolderClick;
    /** @type {?} */
    ToolbarComponent.prototype.onUpload;
    /** @type {?} */
    ToolbarComponent.prototype.onMenuButtonClick;
    /** @type {?} */
    ToolbarComponent.prototype.configuration;
    /** @type {?} */
    ToolbarComponent.prototype.fileManagerUploader;
    /**
     * @type {?}
     * @private
     */
    ToolbarComponent.prototype.store;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileManagerComponent {
    /**
     * @param {?} store
     * @param {?} nodeDispatcherService
     * @param {?} treeService
     * @param {?} configuration
     * @param {?} fileManagerEffects
     * @param {?} filemanagerNotifications
     * @param {?} currentDirectoryFilesService
     * @param {?} treeInitializerService
     */
    constructor(store, nodeDispatcherService, treeService, configuration, fileManagerEffects, filemanagerNotifications, currentDirectoryFilesService, treeInitializerService) {
        this.store = store;
        this.nodeDispatcherService = nodeDispatcherService;
        this.treeService = treeService;
        this.configuration = configuration;
        this.fileManagerEffects = fileManagerEffects;
        this.filemanagerNotifications = filemanagerNotifications;
        this.currentDirectoryFilesService = currentDirectoryFilesService;
        this.treeInitializerService = treeInitializerService;
        this.onSingleFileSelect = new EventEmitter();
        this.treeConfiguration = {
            showAddButton: false,
            disableMoveNodes: false,
            treeId: FILEMANAGER_TREE_NAME,
            dragZone: FILEMANAGER_TREE_NAME,
            dropZone: [FILEMANAGER_TREE_NAME]
        };
        /**
         * UNSED *
         */
        this.contextMenu = [];
        this.currentSelectedFilesIds = [];
        this.currentSelectedFiles = [];
        this.isPreviewMode = false;
        this.isCropMode = false;
        this.subscription = new Subscription();
        this.menu = configuration.contextMenuItems;
        this.subscription.add(this.currentDirectoryFilesService.selectedFiles$
            .subscribe((/**
         * @param {?} data
         * @return {?}
         */
        (data) => {
            this.currentSelectedFilesIds = data;
        })));
        this.subscription.add(combineLatest(this.currentDirectoryFilesService.selectedFiles$, this.currentDirectoryFilesService.entities$)
            .subscribe((/**
         * @param {?} __0
         * @return {?}
         */
        ([ids, entities]) => {
            this.currentSelectedFiles = ids.map((/**
             * @param {?} id
             * @return {?}
             */
            (id) => entities[id]));
        })));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.treeModel = this.treeInitializerService.init(this.treeConfiguration, this.treeService);
        this.subscription.add(this.treeModel.currentSelectedNode$
            .subscribe((/**
         * @param {?} node
         * @return {?}
         */
        (node) => this.currentSelectedFolder = node)));
        /*** START - init files ***/
        this.files$ = this.currentDirectoryFilesService.files$;
        this.filteredFiles$ = this.currentDirectoryFilesService.filteredFiles$;
        this.selectedFiles$ = this.currentDirectoryFilesService.selectedFiles$;
        this.subscription.add(this.treeModel.currentSelectedNode$
            .subscribe((/**
         * @param {?} node
         * @return {?}
         */
        (node) => {
            this.loadFiles(node ? node.id : '');
        })));
        /*** END - init files ***/
        this.subscription.add(this.fileManagerEffects.cropFileSuccess$
            .subscribe((/**
         * @return {?}
         */
        () => {
            this.closeModal();
        })));
    }
    /**
     * @return {?}
     */
    get currentSelectedFolderId() {
        return this.currentSelectedFolder ? this.currentSelectedFolder.id : null;
    }
    /**
     * @return {?}
     */
    onAddFolder() {
        this.treeComponent.onAdd();
    }
    /***********************************************************************
       * FILE EVENTS
       **********************************************************************/
    /**
     * Run when all files are uploaded
     * @param {?} folderId
     * @return {?}
     */
    onUpload(folderId) {
        this.filemanagerNotifications.send({
            type: 'success',
            title: 'File upload',
            message: 'Upload complete',
        });
    }
    /**
     * @param {?} fileEventData
     * @return {?}
     */
    onPreviewFile(fileEventData) {
        this.isPreviewMode = true;
        this.currentSelectedFile = fileEventData.file;
    }
    /**
     * @param {?} fileEventData
     * @return {?}
     */
    onOpenCropFileEditor(fileEventData) {
        this.isCropMode = true;
        this.currentSelectedFile = fileEventData.file;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onSelectFile(event) {
        this.onSingleFileSelect.next(event.getSelectData());
    }
    /**
     * ********************************************************************
     * TOOLBAR EVENTS
     * ********************************************************************
     * @param {?} event
     * @return {?}
     */
    onMenuButtonClick(event) {
        switch (event.name) {
            case Button.CHOOSE_SELECTION:
                this.store.dispatch(new ChooseFilesAction({ files: this.currentSelectedFiles }));
                break;
            case Button.DELETE_SELECTION:
                this.store.dispatch(new DeleteSelectedFilesAction({ files: this.currentSelectedFilesIds }));
                break;
            case Button.SELECT_ALL:
                this.store.dispatch(new SelectAllFilesAction());
                break;
            case Button.UNSELECT_ALL:
                this.store.dispatch(new UnSelectAllFilesAction());
                break;
            case Button.INVERSE_SELECTION:
                this.store.dispatch(new InverseFilesSelectionAction());
                break;
            case Button.REFRESH_FILES_LIST:
                this.reloadFiles();
                break;
        }
    }
    /**
     * ********************************************************************
     * OTHER FUNCTIONS
     * ********************************************************************
     * @param {?} event
     * @return {?}
     */
    keyEvents(event) {
        if (this.isPreviewMode || this.isCropMode) {
            if (event.keyCode === 27) {
                this.closeModal();
            }
        }
    }
    /**
     * @return {?}
     */
    closeModal() {
        this.isPreviewMode = false;
        this.isCropMode = false;
    }
    /**
     * @private
     * @param {?} folderId
     * @return {?}
     */
    loadFiles(folderId) {
        this.store.dispatch(new LoadFilesAction({ folderId: folderId || '' }));
    }
    /**
     * @private
     * @return {?}
     */
    reloadFiles() {
        /** @type {?} */
        const id = this.currentSelectedFolder ? this.currentSelectedFolder.id : '';
        this.loadFiles(id);
    }
}
FileManagerComponent.decorators = [
    { type: Component, args: [{
                selector: 'ri-filemanager',
                providers: [NodeService],
                template: "<div class=\"filemanager-container\">\n  <div class=\"fm-header\">\n    <ri-toolbar\n        #toolbar\n        [currentFolderId]=\"currentSelectedFolderId\"\n        (onAddFolderClick)=\"onAddFolder()\"\n        (onUpload)=\"onUpload($event)\"\n        (onMenuButtonClick)=\"onMenuButtonClick($event)\"\n    ></ri-toolbar>\n  </div>\n  <div class=\"fm-main-box\">\n    <div class=\"folders-box\">\n      <ri-tree [treeModel]=\"treeModel\"></ri-tree>\n    </div>\n    <div class=\"files-box\">\n      <ri-tree-parents-list [treeModel]=\"treeModel\"></ri-tree-parents-list>\n      <ri-files-list [files]=\"filteredFiles$ | async\"\n                     [selectedFiles]=\"selectedFiles$ | async\"\n                     (onPreviewFile)=\"onPreviewFile($event)\"\n                     (onCropFile)=\"onOpenCropFileEditor($event)\"\n                     (onSelectFile)=\"onSelectFile($event)\"\n      ></ri-files-list>\n    </div>\n  </div>\n  <div *ngIf=\"isPreviewMode || isCropMode\" class=\"backdrop\">\n    <div class=\"modal-view\">\n      <div class=\"modal-close\">\n        <i class=\"fa fa-2x fa-times\" (click)=\"closeModal()\"></i>\n      </div>\n      <ri-file-preview *ngIf=\"isPreviewMode\" [files]=\"filteredFiles$ | async\"\n                       [file]=\"currentSelectedFile\"></ri-file-preview>\n      <crop-image *ngIf=\"isCropMode\" [file]=\"currentSelectedFile\"></crop-image>\n    </div>\n  </div>\n</div>\n",
                styles: [".filemanager-container{width:990px;height:700px}.filemanager-container .tree .dropdown{position:relative}.filemanager-container .tree .dropdown-menu{position:fixed!important}.fm-main-box{position:relative;height:100%}.fm-main-box .folders-box{display:block;position:absolute;top:0;bottom:0;width:300px;overflow:hidden;overflow-y:auto}.fm-main-box .files-box{display:block;position:absolute;left:300px;top:0;bottom:0;overflow:hidden;overflow-y:auto}.fm-main-box .files-box ri-tree-parents-list{margin:0 0 10px 20px;display:block}.backdrop{position:fixed;left:0;right:0;top:0;bottom:0;background-color:rgba(0,0,0,.7);z-index:1000}.modal-view{margin:50px auto;max-width:600px}.modal-view .modal-close{text-align:right;margin:5px 0;color:#fff}.modal-view .modal-close .fa{cursor:pointer}"]
            }] }
];
/** @nocollapse */
FileManagerComponent.ctorParameters = () => [
    { type: Store },
    { type: NodeDispatcherService },
    { type: FileManagerApiService },
    { type: FileManagerConfiguration },
    { type: FileManagerEffectsService },
    { type: FilemanagerNotifications },
    { type: CurrentDirectoryFilesService },
    { type: TreeInitializerService }
];
FileManagerComponent.propDecorators = {
    onSingleFileSelect: [{ type: Output }],
    treeComponent: [{ type: ViewChild, args: [TreeComponent, { static: true },] }],
    filesList: [{ type: ViewChild, args: [FilesListComponent, { static: true },] }],
    keyEvents: [{ type: HostListener, args: ['window:keydown', ['$event'],] }]
};
if (false) {
    /** @type {?} */
    FileManagerComponent.prototype.onSingleFileSelect;
    /** @type {?} */
    FileManagerComponent.prototype.treeComponent;
    /** @type {?} */
    FileManagerComponent.prototype.filesList;
    /**
     * List of files for current selected directory
     * @type {?}
     * @private
     */
    FileManagerComponent.prototype.files$;
    /** @type {?} */
    FileManagerComponent.prototype.filteredFiles$;
    /** @type {?} */
    FileManagerComponent.prototype.selectedFiles$;
    /** @type {?} */
    FileManagerComponent.prototype.folders;
    /** @type {?} */
    FileManagerComponent.prototype.treeConfiguration;
    /** @type {?} */
    FileManagerComponent.prototype.treeModel;
    /**
     * UNSED *
     * @type {?}
     */
    FileManagerComponent.prototype.contextMenu;
    /** @type {?} */
    FileManagerComponent.prototype.currentSelectedFile;
    /** @type {?} */
    FileManagerComponent.prototype.currentSelectedFilesIds;
    /** @type {?} */
    FileManagerComponent.prototype.currentSelectedFiles;
    /** @type {?} */
    FileManagerComponent.prototype.isPreviewMode;
    /** @type {?} */
    FileManagerComponent.prototype.isCropMode;
    /**
     * List of context menu
     * @type {?}
     */
    FileManagerComponent.prototype.menu;
    /**
     * @type {?}
     * @protected
     */
    FileManagerComponent.prototype.currentSelectedFolder;
    /**
     * @type {?}
     * @private
     */
    FileManagerComponent.prototype.subscription;
    /**
     * @type {?}
     * @private
     */
    FileManagerComponent.prototype.store;
    /**
     * @type {?}
     * @private
     */
    FileManagerComponent.prototype.nodeDispatcherService;
    /**
     * @type {?}
     * @private
     */
    FileManagerComponent.prototype.treeService;
    /**
     * @type {?}
     * @private
     */
    FileManagerComponent.prototype.configuration;
    /**
     * @type {?}
     * @private
     */
    FileManagerComponent.prototype.fileManagerEffects;
    /**
     * @type {?}
     * @private
     */
    FileManagerComponent.prototype.filemanagerNotifications;
    /**
     * @type {?}
     * @private
     */
    FileManagerComponent.prototype.currentDirectoryFilesService;
    /**
     * @type {?}
     * @private
     */
    FileManagerComponent.prototype.treeInitializerService;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileManagerModule {
    /**
     * @param {?} config
     * @param {?=} apiProvider
     * @return {?}
     */
    static forRoot(config, apiProvider = null) {
        return {
            ngModule: FileManagerModule,
            providers: [
                CurrentDirectoryFilesService,
                FileManagerApiService,
                FileManagerBackendApiService,
                FileManagerConfiguration,
                FileManagerEffectsService,
                FilemanagerNotifications,
                FileManagerUploader,
                FileTypeFilterService,
                ImageDataConverter,
                SearchFilterService,
                TreeService,
                { provide: 'fileManagerConfiguration', useValue: config },
                apiProvider ? apiProvider : FileManagerApiService
            ]
        };
    }
    /**
     * @param {?} config
     * @param {?=} apiProvider
     * @return {?}
     */
    static forChild(config, apiProvider = null) {
        return {
            ngModule: FileManagerModule,
            providers: [
                CurrentDirectoryFilesService,
                FileManagerApiService,
                FileManagerBackendApiService,
                FileManagerConfiguration,
                FileManagerEffectsService,
                FilemanagerNotifications,
                FileManagerUploader,
                FileTypeFilterService,
                ImageDataConverter,
                SearchFilterService,
                TreeService,
                { provide: 'fileManagerConfiguration', useValue: config },
                apiProvider ? apiProvider : FileManagerApiService
            ]
        };
    }
}
FileManagerModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ConfirmationPopoverModule,
                    EffectsModule.forFeature([FileManagerEffectsService]),
                    FormsModule,
                    FileUploadModule,
                    HttpClientModule,
                    ImageCropperModule,
                    ReactiveFormsModule,
                    StoreModule.forFeature('files', fileManagerReducer),
                    TreeModule
                ],
                declarations: [
                    FileManagerComponent,
                    FileComponent,
                    FileTypeFilterComponent,
                    ToolbarComponent,
                    FilesListComponent,
                    DropdownComponent,
                    PreviewComponent,
                    CropComponent,
                    SearchFileComponent,
                    SelectionComponent
                ],
                entryComponents: [
                    ImageCropperComponent
                ],
                exports: [FileManagerComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AbstractFileManagerApiService, Button, ChooseFilesAction, CropComponent, CropFileAction, CropFileErrorAction, CropFileSuccessAction, CurrentDirectoryFilesService, DeleteFileAction, DeleteFileSuccessAction, DeleteSelectedFilesAction, DeleteSelectedFilesSuccessAction, DropdownComponent, ExtendedFileUploader, FILEMANAGER_TRANSLATION_TOKEN, FILEMANAGER_TREE_NAME, FileComponent, FileManagerActionTypes, FileManagerApiService, FileManagerBackendApiService, FileManagerComponent, FileManagerConfiguration, FileManagerEffectsService, FileManagerModule, FileManagerUploader, FileTypeFilterComponent, FileTypeFilterService, FilemanagerNotifications, FilesListComponent, IUploadItemEvent, IUrlConfiguration, ImageDataConverter, InverseFilesSelectionAction, LoadFilesAction, LoadFilesSuccessAction, MoveFilesErrorAction, MoveFilesSuccessAction, PreviewComponent, SearchFileComponent, SearchFilterService, SelectAllFilesAction, SelectFileAction, SelectionComponent, ToolbarComponent, ToolbarEventModel, TreeService, UnSelectAllFilesAction, UnSelectFileAction, UploadFilesAction, UploadFilesErrorAction, UploadFilesSuccessAction, fileManagerReducer, filemanagerStateSelector, getAll, isChangeStateFiles, isChangeStateSelectedFiles };
//# sourceMappingURL=rign-angular2-filemanager.js.map
